@@ -1,21 +1,23 @@
 OC.L10N.register(
     "comments",
     {
-    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> en archivos",
-    "%1$s commented" : "%1$s comentados",
-    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
-    "Comments" : "Comentarios",
-    "Type in a new comment..." : "Ingrese un nuevo comentario...",
+    "Type in a new comment..." : "Escribe un nuevo comentario...",
     "Delete comment" : "Borrar comentario",
     "Post" : "Publicar",
     "Cancel" : "Cancelar",
     "Edit comment" : "Editar comentario",
     "[Deleted user]" : "[Usuario eliminado]",
+    "Comments" : "Comentarios",
     "No other comments available" : "No hay otros comentarios disponibles",
     "More comments..." : "Más comentarios...",
     "Save" : "Guardar",
     "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
     "{count} unread comments" : "{count} comentarios no leídos",
-    "Comment" : "Comentario"
+    "Comment" : "Comentario",
+    "<strong>Comments</strong> for files <em>(always listed in stream)</em>" : "<strong>Comentarios</strong> de archivos <em>(siempre se listarán en stream)</em>",
+    "You commented" : "Has comentado",
+    "%1$s commented" : "%1$s comentados",
+    "You commented on %2$s" : "Has comentado en %2$s",
+    "%1$s commented on %2$s" : "%1$s comentados en %2$s"
 },
 "nplurals=2; plural=(n != 1);");
