@@ -3,7 +3,8 @@
  * @author Jakob Sack <mail@jakobsack.de>
  * @author Joas Schilling <nickvergessen@owncloud.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
- * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
@@ -34,7 +35,7 @@
 		'id' => 'files_index',
 		'order' => 0,
 		'href' => $urlGenerator->linkToRoute('files.view.index'),
-		'icon' => \OCP\Util::imagePath('core', 'places/files.svg'),
+		'icon' => $urlGenerator->imagePath('core', 'places/files.svg'),
 		'name' => $l->t('Files'),
 	];
 });
