@@ -21,14 +21,17 @@ OC.L10N.register(
     "Invalid directory." : "Érvénytelen mappa.",
     "Files" : "Fájlkezelő",
     "All files" : "Az összes állomány",
-    "Favorites" : "Kedvencek",
     "Home" : "Otthoni",
     "Close" : "Bezárás",
+    "Favorites" : "Kedvencek",
     "Upload cancelled." : "A feltöltést megszakítottuk.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} állomány nem tölthető fel, mert ez vagy egy mappa, vagy pedig 0 bájtból áll.",
     "Total file size {size1} exceeds upload limit {size2}" : "A teljes fájlméret: {size1} meghaladja a feltöltési limitet: {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
+    "Error uploading file \"{fileName}\": {message}" : "Hiba történt a fájlfeltöltés közben:  \"{fileName}\": {message}",
     "Could not get result from server." : "A kiszolgálótól nem kapható meg a művelet eredménye.",
+    "Uploading..." : "Feltöltés...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Fájlfeltöltés van folyamatban. Az oldal elhagyása megszakítja a feltöltést.",
     "Actions" : "Műveletek",
     "Download" : "Letöltés",
@@ -104,9 +107,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
     "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
     "Settings" : "Beállítások",
+    "Show hidden files" : "Rejtett fájlok megjelenítése",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Ezt a címet használja, ha <a href=\"%s\" target=\"_blank\">WebDAV-on keresztül szeretné elérni a fájljait</a>",
-    "Cancel upload" : "A feltöltés megszakítása",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Használja ezt a címet <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">a Fájlok eléréséhez WebDAV-on keresztül</a>.",
     "No files in here" : "Itt nincsenek fájlok",
     "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
