@@ -21,14 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "Неверный каталог.",
     "Files" : "Файлы",
     "All files" : "Все файлы",
-    "Favorites" : "Избранное",
+    "File could not be found" : "Файл не может быть найден",
     "Home" : "Главная",
     "Close" : "Закрыть",
+    "Favorites" : "Избранное",
     "Upload cancelled." : "Загрузка отменена.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить {filename}, так как это либо каталог, либо файл нулевого размера",
     "Total file size {size1} exceeds upload limit {size2}" : "Полный размер файла {size1} превышает лимит по загрузке {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, Вы загружаете {size1}, но осталось только {size2}",
+    "Error uploading file \"{fileName}\": {message}" : "Ошибка загрузки файла \"{fileName}\": {message}",
     "Could not get result from server." : "Не удалось получить ответ от сервера.",
+    "Uploading..." : "Загрузка...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "Осталось часов {hours}:{minutes}:{seconds} {plural_s}",
+    "{hours}:{minutes}h" : "{hours}:{minutes}ч",
+    "{minutes}:{seconds} minute{plural_s} left" : "Осталось минут {minutes}:{seconds} {plural_s}",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}м",
+    "{seconds} second{plural_s} left" : "Осталось секунд {seconds} {plural_s}",
+    "{seconds}s" : "{seconds}с",
+    "Any moment now..." : "В любой момент...",
+    "Soon..." : "Скоро...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Идёт загрузка файла. Покинув страницу, вы прервёте загрузку.",
     "Actions" : "Действия",
     "Download" : "Скачать",
@@ -38,7 +51,7 @@ OC.L10N.register(
     "Unshare" : "Закрыть доступ",
     "Details" : "Подробно",
     "Select" : "Выбрать",
-    "Pending" : "Ожидание",
+    "Pending" : "Ожидается",
     "Unable to determine date" : "Невозможно определить дату",
     "This operation is forbidden" : "Операция запрещена",
     "This directory is unavailable, please check the logs or contact the administrator" : "Директория недоступна, пожалуйста проверьте журнал сообщений или свяжитесь с администратором",
@@ -74,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байтов","%n байта(ов)"],
     "Favorited" : "Избранное",
     "Favorite" : "Избранное",
+    "Local link" : "Локальная ссылка",
     "Folder" : "Каталог",
     "New folder" : "Новый каталог",
     "{newname} already exists" : "{newname} уже существует",
@@ -104,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "В режиме PHP-FPM применение изменений может занять до 5 минут.",
     "Missing permissions to edit from here." : "Отсутствуют права на удаление.",
     "Settings" : "Настройки",
+    "Show hidden files" : "Показать скрытые файлы",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\">доступа файлам через WebDAV</a>",
-    "Cancel upload" : "Отменить загрузку",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">для доступа к вашим файлам по WebDAV</a>",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "No entries found in this folder" : "Ничего не найдено",
@@ -116,13 +130,6 @@ OC.L10N.register(
     "No favorites" : "Нет избранного",
     "Files and folders you mark as favorite will show up here" : "Здесь появятся файлы и каталоги, отмеченные как избранные",
     "Text file" : "Текстовый файл",
-    "New text file.txt" : "Новый текстовый документ.txt",
-    "Changed by %2$s" : "Изменено %2$s",
-    "Deleted by %2$s" : "Удалено %2$s",
-    "Restored by %2$s" : "Восстановлено %2$s",
-    "You changed %1$s" : "Вы изменили %1$s",
-    "You created %1$s" : "Вы создали %1$s",
-    "You deleted %1$s" : "Вы удалили %1$s",
-    "You restored %1$s" : "Вы восстановили %1$s"
+    "New text file.txt" : "Новый текстовый документ.txt"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
