@@ -21,15 +21,23 @@ OC.L10N.register(
     "Invalid directory." : "Neveljavna mapa.",
     "Files" : "Datoteke",
     "All files" : "Vse datoteke",
-    "Favorites" : "Priljubljene",
     "Home" : "Domači naslov",
     "Close" : "Zapri",
+    "Favorites" : "Priljubljene",
     "Upload cancelled." : "Pošiljanje je preklicano.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
     "Total file size {size1} exceeds upload limit {size2}" : "Skupna velikost {size1} presega omejitev velikosti {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
     "Error uploading file \"{fileName}\": {message}" : "Napaka pošiljanja datoteke \"{fileName}\": {message}",
     "Could not get result from server." : "Ni mogoče pridobiti podatkov s strežnika.",
+    "Uploading..." : "Poteka pošiljanje ...",
+    "..." : "...",
+    "{hours}:{minutes}h" : "{hours}:{minutes}h",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}min",
+    "{seconds}s" : "{seconds}s",
+    "Any moment now..." : "Vsak trenutek ...",
+    "Soon..." : "Kmalu",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "V teku je pošiljanje datoteke. Če zapustite to stran zdaj, bo pošiljanje preklicano.",
     "Actions" : "Dejanja",
     "Download" : "Prejmi",
@@ -75,6 +83,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
     "Favorited" : "Označeno kot priljubljeno",
     "Favorite" : "Priljubljene",
+    "Local link" : "Krajevna povezava",
     "Folder" : "Mapa",
     "New folder" : "Nova mapa",
     "{newname} already exists" : "{newname} že obstaja",
@@ -105,17 +114,17 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Uveljavljanje sprememb prek PHP-FPM lahko traja tudi 5  minut.",
     "Missing permissions to edit from here." : "Ni ustreznih dovoljenj za urejanje na tej ravni.",
     "Settings" : "Nastavitve",
+    "Show hidden files" : "Pokaži skrite datoteke",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\"> za dostop do datotek peko sistema WebDAV</a>.",
-    "Cancel upload" : "Prekliči pošiljanje",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Uporabite naslov <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> za dostop do datotek prek sistema WebDAV</a>.",
     "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino ali pa omogočite usklajevanje z napravami!",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Select all" : "izberi vse",
     "Upload too large" : "Prekoračenje omejitve velikosti",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
-    "No favorites" : "Ni priljubljenih",
-    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo izpisane tukaj.",
+    "No favorites" : "Ni priljubljenih predmetov",
+    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
     "Text file" : "Besedilna datoteka",
     "New text file.txt" : "Nova datoteka.txt"
 },
