@@ -21,14 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "无效文件夹。",
     "Files" : "文件",
     "All files" : "全部文件",
-    "Favorites" : "收藏",
+    "File could not be found" : "文件未找到",
     "Home" : "家庭",
     "Close" : "关闭",
+    "Favorites" : "收藏",
     "Upload cancelled." : "上传已取消",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "不能上传文件 {filename} ，由于它是一个目录或者为0字节",
     "Total file size {size1} exceeds upload limit {size2}" : "总文件大小 {size1} 超过上传限制 {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "没有足够的可用空间，您正在上传 {size1} 的文件但是只有 {size2} 可用。",
+    "Error uploading file \"{fileName}\": {message}" : "上传文件错误 \"{fileName}\": {message}",
     "Could not get result from server." : "不能从服务器得到结果",
+    "Uploading..." : "上传中...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "剩余时间：{hours}:{minutes}:{seconds} ",
+    "{hours}:{minutes}h" : "{hours}:{minutes}",
+    "{minutes}:{seconds} minute{plural_s} left" : "剩余分钟：{minutes}:{seconds} ",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}",
+    "{seconds} second{plural_s} left" : "剩下{seconds} 秒",
+    "{seconds}s" : "{seconds}秒",
+    "Any moment now..." : "现在任何时候...",
+    "Soon..." : "很快...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中。现在离开此页会导致上传动作被取消。",
     "Actions" : "动作",
     "Download" : "下载",
@@ -74,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n 字节"],
     "Favorited" : "已收藏",
     "Favorite" : "收藏",
+    "Local link" : "本地链接",
     "Folder" : "文件夹",
     "New folder" : "增加文件夹",
     "{newname} already exists" : "{newname} 已经存在",
@@ -104,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
     "Missing permissions to edit from here." : "没有从这里进行编辑的权限",
     "Settings" : "设置",
+    "Show hidden files" : "显示隐藏文件",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\">通过 WebDAV 访问您的文件</a>",
-    "Cancel upload" : "取消上传",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">通过 WebDAV 访问您的文件</a>",
     "No files in here" : "无文件",
     "Upload some content or sync with your devices!" : "上传一些内容或者与设备同步!",
     "No entries found in this folder" : "此文件夹中无项目",
