@@ -1,35 +1,34 @@
 OC.L10N.register(
     "files_external",
     {
+    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Otrzymano błędne żądanie tokenów. Sprawdź, czy klucz aplikacji oraz klucz poufny są poprawne.",
+    "Please provide a valid app key and secret." : "Proszę podać prawidłowy klucz aplikacji i klucz sekretny.",
     "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
     "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
     "External storage" : "Zewnętrzne zasoby dyskowe",
-    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
-    "Invalid mount point" : "Nieprawidłowy punkt montowania",
-    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
     "Personal" : "Osobiste",
     "System" : "System",
     "Grant access" : "Udziel dostępu",
-    "Access granted" : "Dostęp do",
     "Generate keys" : "Wygeneruj klucze",
     "Error generating key pair" : "Błąd podczas generowania pary kluczy",
-    "Enable encryption" : "Włącz szyfrowanie",
-    "Enable previews" : "Włącz podgląd",
-    "Check for changes" : "Sprawdź zmiany",
-    "Never" : "Nigdy",
-    "Once every direct access" : "Jeden raz przy każdym dostępie",
     "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
     "(group)" : "(grupa)",
     "Saved" : "Zapisano",
     "Username" : "Nazwa użytkownika",
     "Password" : "Hasło",
+    "Credentials required" : "Wymagane poświadczenia",
     "Save" : "Zapisz",
+    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
+    "Invalid mount point" : "Nieprawidłowy punkt montowania",
+    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
+    "Access key" : "Klucz dostępu",
     "None" : "Nic",
     "App key" : "Klucz aplikacji",
     "App secret" : "Hasło aplikacji",
     "Client ID" : "ID klienta",
     "Client secret" : "Hasło klienta",
     "API key" : "Klucz API",
+    "RSA public key" : "Klucz publiczny RSA",
     "Public key" : "Klucz publiczny",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "Kosz",
@@ -63,6 +62,11 @@ OC.L10N.register(
     "Name" : "Nazwa",
     "Storage type" : "Typ magazynu",
     "Scope" : "Zakres",
+    "Enable encryption" : "Włącz szyfrowanie",
+    "Enable previews" : "Włącz podgląd",
+    "Check for changes" : "Sprawdź zmiany",
+    "Never" : "Nigdy",
+    "Once every direct access" : "Jeden raz przy każdym dostępie",
     "External Storage" : "Zewnętrzna zasoby dyskowe",
     "Folder name" : "Nazwa folderu",
     "Configuration" : "Konfiguracja",
@@ -70,10 +74,6 @@ OC.L10N.register(
     "Add storage" : "Dodaj zasoby dyskowe",
     "Advanced settings" : "Ustawienia zaawansowane",
     "Delete" : "Usuń",
-    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe",
-    "Access key" : "Klucz dostępu",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla FTP w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
-    "RSA public key" : "Klucz publiczny RSA",
-    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC"
+    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe"
 },
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
