@@ -11,7 +11,6 @@ OC.L10N.register(
     "Shared with you" : "Jaettu kanssasi",
     "Shared with others" : "Jaettu muiden kanssa",
     "Shared by link" : "Jaettu linkin kautta",
-    "Federated sharing" : "Federoitu jakaminen",
     "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
     "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
     "Nothing shared yet" : "Ei mitään jaettua",
@@ -28,6 +27,20 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Virheellinen ownCloud-osoite",
     "Shared by" : "Jakanut",
     "Sharing" : "Jakaminen",
+    "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
+    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
+    "Could not delete share" : "Jaon poistaminen ei onnistunut",
+    "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
+    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
+    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
+    "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
+    "Please specify a valid group" : "Määritä kelvollinen ryhmä",
+    "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
+    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla YYYY-MM-DD",
+    "Not a directory" : "Ei hakemisto",
+    "Could not lock path" : "Polun lukitseminen ei onnistunut",
+    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
+    "Cannot increase permissions" : "Oikeuksien lisääminen ei onnistu",
     "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio jaettiin <strong>toiselta palvelimelta</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Julkisesti jaettu tiedosto tai kansio <strong>ladattiin</strong>",
@@ -59,11 +72,6 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Kohteen %2$s julkinen linkki vanhentui",
     "Shared by %2$s" : "Jakanut %2$s",
     "Shares" : "Jaot",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Vastaanotit kohteen \"/%2$s\" etäjakona käyttäjältä %1$s",
-    "Accept" : "Hyväksy",
-    "Decline" : "Kieltäydy",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta, katso %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta",
     "This share is password-protected" : "Tämä jako on suojattu salasanalla",
     "The password is wrong. Try again." : "Väärä salasana. Yritä uudelleen.",
     "Password" : "Salasana",
@@ -79,23 +87,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Lisää ownCloudiisi",
     "Download" : "Lataa",
     "Download %s" : "Lataa %s",
-    "Direct link" : "Suora linkki",
-    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
-    "Open documentation" : "Avaa dokumentaatio",
-    "Allow users on this server to send shares to other servers" : "Salli tämän palvelimen käyttäjien lähettää jakoja muille palvelimille",
-    "Allow users on this server to receive shares from other servers" : "Salli tämän palvelimen käyttäjien vastaanottaa jakoja muilta palvelimilta",
-    "Federated Cloud" : "Federoitu pilvi",
-    "Your Federated Cloud ID:" : "Federoidun pilvesi tunniste:",
-    "Share it:" : "Jaa se:",
-    "Add to your website" : "Lisää verkkosivuillesi",
-    "Share with me via ownCloud" : "Jaa kanssani ownCloudin kautta",
-    "HTML Code:" : "HTML-koodi:",
-    "Public link of %2$s expired" : "Kohteen %2$s julkinen linkki vanhentui",
-    "Public shared file %1$s was downloaded" : "Julkisesti jaettu tiedosto %1$s ladattiin",
-    "Public shared folder %1$s was downloaded" : "Julkisesti jaettu kansio %1$s ladattiin",
-    "Shared by %2$s" : "Jakanut %2$s",
-    "Shared via link by %2$s" : "Jaettu linkin kautta käyttäjän %2$s toimesta",
-    "Shared with group %3$s by %2$s" : "Jaettu ryhmän %3$s kanssa käyttäjän %2$s toimesta",
-    "Your public link for %1$s expired" : "Julkinen linkkisi kohteelle %1$s vanhentui"
+    "Direct link" : "Suora linkki"
 },
 "nplurals=2; plural=(n != 1);");
