@@ -11,7 +11,6 @@ OC.L10N.register(
     "Shared with you" : "Compartilhado com você",
     "Shared with others" : "Compartilhado com outros",
     "Shared by link" : "Compartilhado por link",
-    "Federated sharing" : "Compartilhamento associado",
     "Nothing shared with you yet" : "Nada compartilhado com você até agora",
     "Files and folders others share with you will show up here" : "Arquivos e pastas que outros compartilham com você são mostrados aqui",
     "Nothing shared yet" : "Nada compartilhado até agora",
@@ -28,6 +27,25 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Url invalida para ownCloud",
     "Shared by" : "Compartilhado por",
     "Sharing" : "Compartilhamento",
+    "Share API is disabled" : "O compartilhamento de API está desabilitado.",
+    "Wrong share ID, share doesn't exist" : "ID de compartilhamento errado, o compartilhamento não existe",
+    "Could not delete share" : "Não foi possível eliminar o compartilhamento",
+    "Please specify a file or folder path" : "Por favor especifique um arquivo ou caminho",
+    "Wrong path, file/folder doesn't exist" : "Caminho errado, arquivo/pasta não existe",
+    "Please specify a valid user" : "Por favor especifique um usuário válido",
+    "Group sharing is disabled by the administrator" : "Grupo de compartilhamento foi desabilitado pelo administrador",
+    "Please specify a valid group" : "Por favor especifique um grupo válido",
+    "Public link sharing is disabled by the administrator" : "Link de compartilhamento público foi desativado pelo administrador",
+    "Public upload disabled by the administrator" : "Envio público foi desativado pelo administrador",
+    "Public upload is only possible for publicly shared folders" : "Envio pública só é possível para pastas compartilhadas publicamente",
+    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato de data deve ser YYYY-MM-DD",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "O compartilhando %s falhou porque o backend não permite ações de tipo %s",
+    "Unknown share type" : "Tipo de compartilhamento desconhecido",
+    "Not a directory" : "Não é um diretório",
+    "Could not lock path" : "Não foi possível bloquear o caminho",
+    "Can't change permissions for public share links" : "Não é possível alterar permissões para compartilhar links públicos",
+    "Wrong or no update parameter given" : "Está errado ou nenhum parâmetro de atualização foi fornecido",
+    "Cannot increase permissions" : "Não pode haver aumento de permissões",
     "A file or folder has been <strong>shared</strong>" : "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
     "A file or folder was shared from <strong>another server</strong>" : "Um arquivo ou pasta foi compartilhado a partir de <strong>outro servidor</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Um arquivo ou pasta compartilhado publicamente foi <strong>baixado</strong>",
@@ -71,11 +89,6 @@ OC.L10N.register(
     "Public link of %2$s expired" : "O link público de %2$s expirou",
     "Shared by %2$s" : "Compartilhado por %2$s",
     "Shares" : "Compartilhamentos",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Você recebeu \"/%2$s\" como um compartilhamento remoto de %1$s",
-    "Accept" : "Aceitar",
-    "Decline" : "Rejeitar",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Associada, veja %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Associada",
     "This share is password-protected" : "Este compartilhamento esta protegido por senha",
     "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
     "Password" : "Senha",
@@ -91,16 +104,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Adiconar ao seu ownCloud",
     "Download" : "Baixar",
     "Download %s" : "Baixar %s",
-    "Direct link" : "Link direto",
-    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Associada",
-    "Open documentation" : "Abrir documentação",
-    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
-    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários nesse servidor recebam compartilhamentos de outros servidores",
-    "Federated Cloud" : "Nuvem Associada",
-    "Your Federated Cloud ID:" : "Sua ID na Nuvem Associada:",
-    "Share it:" : "Compartilhe:",
-    "Add to your website" : "Adicione ao seu website",
-    "Share with me via ownCloud" : "Compartilhe comigo via ownCloud",
-    "HTML Code:" : "Código HTML:"
+    "Direct link" : "Link direto"
 },
 "nplurals=2; plural=(n > 1);");
