@@ -1,4 +1,34 @@
 <?php
+/**
+ * @author Andreas Fischer <bantu@owncloud.com>
+ * @author Bart Visscher <bartv@thisnet.nl>
+ * @author Björn Schießle <bjoern@schiessle.org>
+ * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author Michael Gapczynski <GapczynskiM@gmail.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Roeland Jago Douma <rullzer@owncloud.com>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Vincent Petry <pvince81@owncloud.com>
+ *
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ *
+ */
+use OCA\FederatedFileSharing\FederatedShareProvider;
+
 /**
  * @author Andreas Fischer <bantu@owncloud.com>
  * @author Bart Visscher <bartv@thisnet.nl>
@@ -40,6 +70,18 @@ class OC_Share_Backend_File implements OCP\Share_Backend_File_Dependent {
 
 	private $path;
 
+	/** @var FederatedShareProvider */
+	private $federatedShareProvider;
+
+	public function __construct(FederatedShareProvider $federatedShareProvider = null) {
+		if ($federatedShareProvider) {
+			$this->federatedShareProvider = $federatedShareProvider;
+		} else {
+			$federatedSharingApp = new \OCA\FederatedFileSharing\AppInfo\Application('federatedfilesharing');
+			$this->federatedShareProvider = $federatedSharingApp->getFederatedShareProvider();
+		}
+	}
+
 	public function isValidSource($itemSource, $uidOwner) {
 		try {
 			$path = \OC\Files\Filesystem::getPath($itemSource);
@@ -173,7 +215,7 @@ class OC_Share_Backend_File implements OCP\Share_Backend_File_Dependent {
 	 */
 	public function isShareTypeAllowed($shareType) {
 		if ($shareType === \OCP\Share::SHARE_TYPE_REMOTE) {
-			return \OCA\Files_Sharing\Helper::isOutgoingServer2serverShareEnabled();
+			return $this->federatedShareProvider->isOutgoingServer2serverShareEnabled();
 		}
 
 		return true;
