@@ -1,7 +1,10 @@
 <?php
 $TRANSLATIONS = array(
+"This file is too big to be opened. Please download the file instead." => "Denne filen er for stor til å bli åpnet. Last ned filen i stedet.",
 "Cannot read the file." => "Kan ikke lese filen.",
 "Invalid file path supplied." => "Ugyldig sti angitt.",
+"The file is locked." => "Filen er låst.",
+"An internal server error occurred." => "En intern serverfeil oppstod.",
 "Cannot save file as it has been modified since opening" => "Kan ikke lagre filen siden den har blitt endret.",
 "Insufficient permissions" => "Ikke rettigheter",
 "File path not supplied" => "Filbane ikke angitt",
@@ -11,6 +14,8 @@ $TRANSLATIONS = array(
 "failed!" => "feilet!",
 "Saved" => "Lagret",
 "There was a problem saving your changes. Click to resume editing." => "Det oppstod et problem ved lagring av endringene dine. Klikk for å fortsette redigering.",
-"An error occurred!" => "En feil oppstod!"
+"An error occurred!" => "En feil oppstod!",
+"Text file" => "Tekstfil",
+"New text file.txt" => "Ny tekstfil.txt"
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
