@@ -1,6 +1,8 @@
 <?php
 /**
- * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
@@ -20,10 +22,9 @@
  */
 
 if(\OC::$server->getConfig()->getSystemValue('updatechecker', true) === true) {
-	$updater = new \OC\Updater(
-		\OC::$server->getHTTPHelper(),
-		\OC::$server->getConfig(),
-		\OC::$server->getIntegrityCodeChecker()
+	$updater = new \OC\Updater\VersionCheck(
+		\OC::$server->getHTTPClientService(),
+		\OC::$server->getConfig()
 	);
 	$updateChecker = new \OCA\UpdateNotification\UpdateChecker(
 		$updater
@@ -39,4 +40,18 @@ if(\OC::$server->getConfig()->getSystemValue('updatechecker', true) === true) {
 			\OC_App::registerAdmin('updatenotification', 'admin');
 		}
 	}
+
+	$manager = \OC::$server->getNotificationManager();
+	$manager->registerNotifier(function() use ($manager) {
+		return new \OCA\UpdateNotification\Notification\Notifier(
+			$manager,
+			\OC::$server->getL10NFactory()
+		);
+	}, function() {
+		$l = \OC::$server->getL10N('updatenotification');
+		return [
+			'id' => 'updatenotification',
+			'name' => $l->t('Update notifications'),
+		];
+	});
 }
