@@ -1,13 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "﻿ಕೆಳಗಿನ ಬಳಕೆದಾರರಿಗೆ ಈ-ಮೇಲ್ ಕಳುಹಿಸಿ ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ: %s",
-    "Turned on maintenance mode" : "ನಿರ್ವಹಣೆಯ ಸ್ತಿತಿಯನ್ನು ಆರಂಭಿಸಲಾಗಿದೆ",
-    "Turned off maintenance mode" : "ನಿರ್ವಹಣೆಯ ಸ್ತಿತಿಯನ್ನು ಮುಕ್ತಗೊಳಿಸಲಾಗಿದೆ",
-    "Updated database" : "ದತ್ತಸಂಚಯ ",
-    "Checked database schema update" : "﻿ಪರಿಶೀಲಿಸಿದ ದತ್ತಸಂಚಯ ಯೋಜನಾ ಅಪ್ಡೇಟ್",
-    "Checked database schema update for apps" : "ನವೀಕರಿಸಿದ ದತ್ತಸಂಚಯದ ಯೋಜನಾ ಪ್ರತಿಗಳನ್ನು ಕಾಯಕ್ರಮಗಳೊಂದಿಗೆ ಪರಿಶೀಲಿಸಲಾಗಿದೆ",
-    "Updated \"%s\" to %s" : "﻿%s ರ ಆವೃತ್ತಿ %s ನ್ನು ನವೀಕರಿಸಲಾಗುತ್ತದೆ.",
     "No image or file provided" : "ಚಿತ್ರ ಅಥವಾ ಕಡತದ ಕೊರತೆ ಇದೆ",
     "Unknown filetype" : "﻿ಅಪರಿಚಿತ ಕಡತ ಮಾದರಿ",
     "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
@@ -17,6 +10,20 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "ಬದಲಾವಣೆಯ ಇ-ಅಂಚೆಯನ್ನು ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ. ನಿಮ್ಮ ಬಳಕೆದಾರ ಹೆಸರು ಸರಿಯಾಗಿದೆ ಖಚಿತಪಡಿಸಿಕೊಳ್ಳಿ.",
     "%s password reset" : "%s ಗುಪ್ತ ಪದವನ್ನು ಮರುಹೊಂದಿಸಿ",
     "Couldn't send reset email. Please contact your administrator." : "﻿ರೀಸೆಟ್ ಇಮೇಲ್ ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.",
+    "Error loading tags" : "﻿ಕಿರು ಪದಗಳನ್ನ ಪಡೆಯುವಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
+    "Tag already exists" : "ಕಿರು ಪದ ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ",
+    "Error deleting tag(s)" : "﻿ಕಿರು-ಪದ(ಗಳನ್ನು) ಅಳಿಸುವಲ್ಲಿ ಲೋಪವಾದೆ",
+    "Error tagging" : "ಕಿರು-ಪದ ಅಸ್ತಿತ್ವಗೂಳಿಸಲಯ ",
+    "Error untagging" : "ಕಿರು-ಪದವನ್ನು ತೆರುವುಗೂಳಿಸುವಲಿ್ಲ ದೋಷ",
+    "Error favoriting" : "ಒಲವು ತೋರಿಸುವಲ್ಲಿ ದೋಷ",
+    "Error unfavoriting" : "ಒಲವು ಬದಲಾಯಿಸುವಲ್ಲಿ ದೋಷ",
+    "Couldn't send mail to following users: %s " : "﻿ಕೆಳಗಿನ ಬಳಕೆದಾರರಿಗೆ ಈ-ಮೇಲ್ ಕಳುಹಿಸಿ ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ: %s",
+    "Turned on maintenance mode" : "ನಿರ್ವಹಣೆಯ ಸ್ತಿತಿಯನ್ನು ಆರಂಭಿಸಲಾಗಿದೆ",
+    "Turned off maintenance mode" : "ನಿರ್ವಹಣೆಯ ಸ್ತಿತಿಯನ್ನು ಮುಕ್ತಗೊಳಿಸಲಾಗಿದೆ",
+    "Updated database" : "ದತ್ತಸಂಚಯ ",
+    "Checked database schema update" : "﻿ಪರಿಶೀಲಿಸಿದ ದತ್ತಸಂಚಯ ಯೋಜನಾ ಅಪ್ಡೇಟ್",
+    "Checked database schema update for apps" : "ನವೀಕರಿಸಿದ ದತ್ತಸಂಚಯದ ಯೋಜನಾ ಪ್ರತಿಗಳನ್ನು ಕಾಯಕ್ರಮಗಳೊಂದಿಗೆ ಪರಿಶೀಲಿಸಲಾಗಿದೆ",
+    "Updated \"%s\" to %s" : "﻿%s ರ ಆವೃತ್ತಿ %s ನ್ನು ನವೀಕರಿಸಲಾಗುತ್ತದೆ.",
     "Sunday" : "﻿ಭಾನುವಾರ",
     "Monday" : "﻿ಸೋಮವಾರ",
     "Tuesday" : "﻿ಮಂಗಳವಾರ",
@@ -73,8 +80,6 @@ OC.L10N.register(
     "Expiration" : "﻿ಮುಕ್ತಾಯ",
     "Expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕ",
     "Choose a password for the public link" : "ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿಗೆ ಗುಪ್ತಪದ ಆಯ್ಕೆಮಾಡಿ",
-    "Sending ..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
-    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
     "Resharing is not allowed" : "﻿ಮರುಹಂಚಿಕೆ ಅನುಮತಿಸಲಾಗುವುದಿಲ್ಲ",
     "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
     "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
@@ -83,6 +88,8 @@ OC.L10N.register(
     "Allow editing" : "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
     "Email link to person" : "ಬಳಕೆದಾರನ ಇ-ಅಂಚೆಯ ಸಂಪರ್ಕಕೊಂಡಿ",
     "Send" : "﻿ಕಳುಹಿಸಿ",
+    "Sending ..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
+    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
     "Shared with you and the group {group} by {owner}" : "ನಿಮಗೆ ಮತ್ತು {group} ಗುಂಪಿನೂಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
     "Shared with you by {owner}" : "﻿ನಿಮ್ಮೊಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
     "group" : "﻿ಗುಂಪು",
@@ -110,19 +117,11 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "ನಮಸ್ಕಾರ {name}, ಸದ್ಯ {weather} ಹವಾಮಾನವಿದೆ",
     "_download %n file_::_download %n files_" : ["%n ಕಡತಗಳನ್ನು ಸ್ಥಳೀಯ ಪ್ರತಿಯಾಗಿಸಿ"],
     "Please reload the page." : "﻿ಪುಟವನ್ನು ಪುನಃ ನವೀಕರಿಸಿ.",
-    "The update was unsuccessful. " : "ಆಧುನೀಕರಿಣೆ ಯಶಸ್ವಿಯಾಗಿಲ್ಲ.",
     "Personal" : "﻿ವೈಯಕ್ತಿಕ",
     "Users" : "﻿ಬಳಕೆದಾರರು",
     "Apps" : "ಕಾರ್ಯಕ್ರಮಗಳು",
     "Admin" : "﻿ನಿರ್ವಹಕ",
     "Help" : "﻿ಸಹಾಯ",
-    "Error loading tags" : "﻿ಕಿರು ಪದಗಳನ್ನ ಪಡೆಯುವಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
-    "Tag already exists" : "ಕಿರು ಪದ ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ",
-    "Error deleting tag(s)" : "﻿ಕಿರು-ಪದ(ಗಳನ್ನು) ಅಳಿಸುವಲ್ಲಿ ಲೋಪವಾದೆ",
-    "Error tagging" : "ಕಿರು-ಪದ ಅಸ್ತಿತ್ವಗೂಳಿಸಲಯ ",
-    "Error untagging" : "ಕಿರು-ಪದವನ್ನು ತೆರುವುಗೂಳಿಸುವಲಿ್ಲ ದೋಷ",
-    "Error favoriting" : "ಒಲವು ತೋರಿಸುವಲ್ಲಿ ದೋಷ",
-    "Error unfavoriting" : "ಒಲವು ಬದಲಾಯಿಸುವಲ್ಲಿ ದೋಷ",
     "Access forbidden" : "﻿ಪ್ರವೇಶ ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ",
     "File not found" : "ಕಡತ ಕಂಡುಬಂದಿಲ್ಲ",
     "You can click here to return to %s." : "ಮರಳಿ ಹೋಗುಲು ಇಲ್ಲಿ ಆಯ್ಕೆ ಮಾಡಿ %s",
@@ -158,7 +157,6 @@ OC.L10N.register(
     "This ownCloud instance is currently in single user mode." : "ಪ್ರಸ್ತುತ ಕ್ರಮದಲ್ಲಿ, ಈ OwnCloud ನ್ನು ಕೇವಲ ಒಬ್ಬನೇ ಬಳಕೆದಾರ ಮಾತ್ರ ಬಳಸಬಹುದಾಗಿದೆ.",
     "This means only administrators can use the instance." : "ಇದರ ಅರ್ಥ, ಸದ್ಯದ ನಿದರ್ಶನದಲ್ಲಿ ನಿರ್ವಾಹಕರು ಮಾತ್ರ ಬಳಸಬಹುದಾಗಿದೆ.",
     "Thank you for your patience." : "﻿ನಿಮ್ಮ ತಾಳ್ಮೆಗೆ ಧನ್ಯವಾದಗಳು.",
-    "Start update" : "ನವೀಕರಿಣವನ್ನು ಆರಂಭಿಸಿ",
-    "Password can not be changed. Please contact your administrator." : "ಗುಪ್ತಪದ ಬದಲಾವಣೆ ಸಾಧ್ಯವಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ."
+    "Start update" : "ನವೀಕರಿಣವನ್ನು ಆರಂಭಿಸಿ"
 },
 "nplurals=1; plural=0;");
