@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "S’u dërgua dot e-mail përdoruesve vijues: %s ",
-    "Preparing update" : "Po përgatitet përditësimi",
-    "Turned on maintenance mode" : "Mënyra e mirëmbajtjes u aktivizua",
-    "Turned off maintenance mode" : "Mënyra e mirëmbajtjes u çaktivizua",
-    "Maintenance mode is kept active" : "Mënyra mirëmbajtje është mbajtur e aktivizuar",
-    "Updating database schema" : "Po përditësohet skema e bazës së të dhënave",
-    "Updated database" : "U përditësua baza e të dhënave",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
-    "Checked database schema update" : "U kontrollua përditësimi i skemës së bazës së të dhënave",
-    "Checking updates of apps" : "Po kontrollohen përditësime të aplikacionit",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave për %s (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
-    "Checked database schema update for apps" : "U kontrollua përditësimi i skemës së bazës së të dhënave për aplikacionet",
-    "Updated \"%s\" to %s" : "U përditësua \"%s\" në %s",
-    "Repair warning: " : "Sinjalizim ndreqjeje: ",
-    "Repair error: " : "Gabim ndreqjeje: ",
-    "Set log level to debug" : "Caktoni shkallë regjistrimi për diagnostikimin",
-    "Reset log level" : "Rikthe te parazgjedhja shkallën e regjistrimit",
-    "Starting code integrity check" : "Po fillohet kontroll integriteti për kodin",
-    "Finished code integrity check" : "Përfundoi kontrolli i integritetit për kodin",
-    "%s (3rdparty)" : "%s (prej palësh të treta)",
-    "%s (incompatible)" : "%s (e papërputhshme)",
-    "Following apps have been disabled: %s" : "Janë çaktivizuar aplikacionet vijuese : %s",
-    "Already up to date" : "Tashmë e përditësuar",
     "Please select a file." : "Ju lutemi, përzgjidhni një kartelë.",
     "File is too big" : "Kartela është shumë e madhe",
     "Invalid file provided" : "U dha kartelë e pavlefshme",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "S’u dërgua dot email ricaktimi, ngaqë s’ka adresë email për këtë përdoruesi. Ju lutemi, lidhuni me përgjegjësin tuaj.",
     "%s password reset" : "U ricaktua fjalëkalimi për %s",
     "Couldn't send reset email. Please contact your administrator." : "S’u dërgua dot email-i i ricaktimit. Ju lutemi, lidhuni me përgjegjësin tuaj.",
+    "Error loading tags" : "Gabim gjatë ngarkimit të etiketave",
+    "Tag already exists" : "Etiketa ekziston",
+    "Error deleting tag(s)" : "Gabim gjatë fshirjes së etiketës(ave)",
+    "Error tagging" : "Gabim etiketimi",
+    "Error untagging" : "Gabim në heqjen e etiketës",
+    "Error favoriting" : "Gabim në ruajtjen si të parapëlqyer",
+    "Error unfavoriting" : "Gabim në heqjen nga të parapëlqyerat",
+    "Couldn't send mail to following users: %s " : "S’u dërgua dot e-mail përdoruesve vijues: %s ",
+    "Preparing update" : "Po përgatitet përditësimi",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Sinjalizim ndreqjeje: ",
+    "Repair error: " : "Gabim ndreqjeje: ",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse përditësimi i vetvetishëm është i çaktivizuar te config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Po kontrollohet tabela %s",
+    "Turned on maintenance mode" : "Mënyra e mirëmbajtjes u aktivizua",
+    "Turned off maintenance mode" : "Mënyra e mirëmbajtjes u çaktivizua",
+    "Maintenance mode is kept active" : "Mënyra mirëmbajtje është mbajtur e aktivizuar",
+    "Updating database schema" : "Po përditësohet skema e bazës së të dhënave",
+    "Updated database" : "U përditësua baza e të dhënave",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
+    "Checked database schema update" : "U kontrollua përditësimi i skemës së bazës së të dhënave",
+    "Checking updates of apps" : "Po kontrollohen përditësime të aplikacionit",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave për %s (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
+    "Checked database schema update for apps" : "U kontrollua përditësimi i skemës së bazës së të dhënave për aplikacionet",
+    "Updated \"%s\" to %s" : "U përditësua \"%s\" në %s",
+    "Set log level to debug" : "Caktoni shkallë regjistrimi për diagnostikimin",
+    "Reset log level" : "Rikthe te parazgjedhja shkallën e regjistrimit",
+    "Starting code integrity check" : "Po fillohet kontroll integriteti për kodin",
+    "Finished code integrity check" : "Përfundoi kontrolli i integritetit për kodin",
+    "%s (3rdparty)" : "%s (prej palësh të treta)",
+    "%s (incompatible)" : "%s (e papërputhshme)",
+    "Following apps have been disabled: %s" : "Janë çaktivizuar aplikacionet vijuese : %s",
+    "Already up to date" : "Tashmë e përditësuar",
     "Sunday" : "E dielë",
     "Monday" : "E hënë",
     "Tuesday" : "E martë",
@@ -88,6 +98,7 @@ OC.L10N.register(
     "Dec." : "Dhj.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Pati probleme me kontrollin e integritetit të kodit. Më tepër të dhëna…</a>",
     "Settings" : "Rregullime",
+    "Problem loading page, reloading in 5 seconds" : "Gabim në ngarkimin e faqes, do të ringarkohet pas 5 sekondash",
     "Saving..." : "Po ruhet …",
     "Dismiss" : "Mos e merr parasysh",
     "seconds ago" : "sekonda më parë",
@@ -119,18 +130,18 @@ OC.L10N.register(
     "Good password" : "Fjalëkalim i mirë",
     "Strong password" : "Fjalëkalim i fortë",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Shërbyesi juaj web ende s’është rregulluar për të lejuar njëkohësim kartelash, ngaqë ndërfaqja WebDAV duket se është e dëmtuar.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Shërbyesi juaj s’është rregulluar si duhet për të kuptuar \"{url}\". Të dhëna të mëtejshme mund të gjenden te <a target=\"_blank\" href=\"{docLink}\">dokumentimi</a> ynë.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Shërbyesi juaj s’është rregulluar si duhet për të kuptuar \"{url}\". Të dhëna të mëtejshme mund të gjenden te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Ky shërbyes nuk ka lidhje Internet që funksionon. Kjo do të thotë që disa prej veçorive, të tilla si montimi i depozitave të jashtme, njoftimet mbi përditësime apo instalim aplikacionesh nga palë të treta, s’do të funksionojnë. Edhe hyrja në kartela së largëti, apo dërgimi i email-eve për njoftime mund të mos funksionojnë. Këshillojmë të aktivizoni për këtë shërbyes lidhjen në Internet, nëse doni t’i keni krejt këto veçori.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "S’është formësuar ndonjë fshehtinë kujtese. Që të përmirësohet punimi juaj, ju lutemi, formësoni një fshehtinë kujtese, në pastë. Të dhëna të mëtejshme mund të gjenden te <a target=\"_blank\" href=\"{docLink}\">dokumentimi</a> ynë.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom s’është i lexueshëm nga PHP-ja, çka shkëshillohet me forcë, për arsye sigurie. Më tepër informacion mund të gjendet te <a target=\"_blank\" href=\"{docLink}\">dokumentimi</a> ynë.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Versioni juaj i PHP-së ({version}) nuk <a target=\"_blank\" href=\"{phpLink}\">mbulohet më nga PHP-ja</a>. Ju nxisim ta përmirësoni versionin tuaj të PHP-së që të përfitoni nga përditësimet e funksionimit dhe sigurisë të ofruara nga PHP-ja.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Formësimi për krye ndërmjetësi prapësor është i pasaktë, ose jeni duke hyrë në ownCloud prej një ndërmjetësi të besuar. Nëse s’jeni duke hyrë në ownCloud prej një ndërmjetësi të besuar, ky është një problem sigurie dhe mund t’i lejojë një agresori të maskojë adresën e vet IP si një të pranueshme nga ownCloud-i. Të dhëna të mëtejshme mund të gjeni te <a target=\"_blank\" href=\"{docLink}\">dokumentimi</a> ynë.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached është formësuar si fshehtinë e shpërndarë, por është instaluar moduli i gabuar PHP \"memcache\". \\OC\\Memcache\\Memcached mbulon vetëm \"memcached\" dhe jo \"memcache\". Shihni <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki për të dy modulet</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Disa prej kartelave s’e kaluan dot kontrollin e integritetit. Si si mund të zgjidhet ky problem mund ta shihni më në thellësi te <a target=\"_blank\" href=\"{docLink}\">dokumentimi ynë</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listë e kartelave të pavlefshme…</a> / <a href=\"{rescanEndpoint}\">Rikontrolloji…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "S’ka të formësuar fshehtinë kujtese. Që të përmirësoni punimin, ju lutemi formësoni një të tillë, në pastë. Më tepër të dhëna mund të gjeni te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom s’lexohet dot nga PHP-ja, çka shkëshillohet me forcë, për arsye sigurie. Më tepër të dhëna mund të gjenden te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Po xhironi PHP {version}. Ju nxisim të përmirësoni versionin e PHP-së që të përfitoni <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">nga përditësimet e punimit dhe sigurisë të ofruara PHP Group</a>, sapo të mbulohet nga shpërndarja juaj.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Formësimi për krye ndërmjetësi prapësor është i pasaktë, ose jeni duke hyrë në ownCloud prej një ndërmjetësi të besuar. Nëse s’jeni duke hyrë në ownCloud prej një ndërmjetësi të besuar, ky është një problem sigurie dhe mund t’i lejojë një agresori të maskojë adresën e vet IP si një të pranueshme nga ownCloud-i. Të dhëna të mëtejshme mund të gjeni te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached është formësuar si fshehtinë e shpërndarë, por është instaluar moduli i gabuar PHP \"memcache\". \\OC\\Memcache\\Memcached mbulon vetëm \"memcached\" dhe jo \"memcache\". Shihni <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki-n mbi memcached rreth të dy moduleve</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Disa kartela s’e kaluan dot kontrollin e pacenueshmërisë. Më tepër të dhëna se si të zgjidhet ky problem mund të gjeni te <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentimi</a> ynë. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listë e kartelave të pavlefshme…</a> / <a href=\"{rescanEndpoint}\">Rikontrollojini…</a>)",
     "Error occurred while checking server setup" : "Ndodhi një gabim gjatë kontrollit të rregullimit të shërbyesit",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Drejtoria juaj e të dhënave dhe kartelat tuaja ka shumë mundësi të jenë të arritshme që nga interneti. Kartela .htaccess s’funksionon. Këshillojmë me forcë që ta formësoni shërbyesin tuaj web në një mënyrë që drejtoria e të dhënave të mos lejojë më hyrje, ose ta zhvendosni drejtorinë e të dhënave jashtë rrënjës së dokumenteve të shërbyesit web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Kryet HTTP \"{header}\" s’është formësuar të jetë i njëjtë me \"{expected}\". Ky është një rrezik potencial sigurie dhe privatësie dhe këshillojmë të ndreqet ky rregullim.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "Kryet HTTP \"Strict-Transport-Security\" s’është formësuar të paktën \"{seconds}\". Për siguri të thelluar këshillojmë aktivizimin e HSTS-së, siç përshkruhet te <a href=\"{docUrl}\">këshillat tona mbi sigurinë</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Parametri \"Strict-Transport-Security\" HTTP s’është formësuar të paktën \"{seconds}\" sekonda. Për siguri të thelluar, ju këshillojmë aktivizimin e HSTS-së, ashtu si përshkruhet në <a href=\"{docUrl}\" rel=\"noreferrer\">këshillat tona mbi sigurinë</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Po e përdorni këtë sajt përmes HTTP-je. Këshillojmë me forcë ta formësoni shërbyesin tuaj të kërkojë medoemos përdorimin e HTTPS-së, siç përshkruhet te <a href=\"{docUrl}\">këshillat tona mbi sigurinë</a>.",
     "Shared" : "Ndarë",
     "Shared with {recipients}" : "Ndarë me {recipients}",
@@ -143,8 +154,6 @@ OC.L10N.register(
     "Expiration" : "Skadim",
     "Expiration date" : "Datë skadimi",
     "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
-    "Sending ..." : "Po dërgohet …",
-    "Email sent" : "Email-i u dërgua",
     "Resharing is not allowed" : "Nuk lejohen rindarjet",
     "Share link" : "Lidhje ndarjeje",
     "Link" : "Lidhje",
@@ -153,6 +162,9 @@ OC.L10N.register(
     "Allow editing" : "Lejo përpunim",
     "Email link to person" : "Dërgoja personit lidhjen me email",
     "Send" : "Dërgoje",
+    "Sending ..." : "Po dërgohet …",
+    "Email sent" : "Email-i u dërgua",
+    "Send link via email" : "Dërgojeni lidhjen me email",
     "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
     "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
     "group" : "grup",
@@ -168,19 +180,22 @@ OC.L10N.register(
     "Could not unshare" : "S’e shndau dot",
     "Share details could not be loaded for this item." : "Për këtë objekt s’u ngarkuan dot hollësi ndarjeje.",
     "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {search}",
-    "An error occured. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
+    "No users found for {search}" : "S’u gjet përdorues për {search}",
+    "An error occurred. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
     "{sharee} (group)" : "{sharee} (grup)",
     "{sharee} (at {server})" : "{sharee} (në {server})",
     "{sharee} (remote)" : "{sharee} (i largët)",
     "Share" : "Ndaje",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Ndajeni me persona në ownCloud-e të tjera duke përdorur sintaksën username@example.com/owncloud",
-    "Share with users or groups …" : "Ndajeni me përdorues ose grupe …",
-    "Share with users, groups or remote users …" : "Ndajeni me përdorues, grupe ose përdorues të largët …",
+    "Share with users…" : "Ndajeni me përdorues…",
+    "Share with users, groups or remote users…" : "Ndajeni me përdorues, grupe ose përdorues të largët…",
+    "Share with users or groups…" : "Ndajeni me përdorues ose grupe…",
+    "Share with users or remote users…" : "Ndajeni me përdorues ose përdorues të largët…",
     "Error removing share" : "Gabim në heqjen e ndarjes",
     "Warning" : "Kujdes",
     "Error while sending notification" : "Gabim gjatë dërgimit të njoftimit",
     "Non-existing tag #{tag}" : "Etiketë #{tag} që s’ekziston",
-    "not assignable" : "e pacaktueshme",
+    "restricted" : "e kufizuar",
     "invisible" : "e padukshme",
     "({scope})" : "({scope})",
     "Delete" : "Fshije",
@@ -197,13 +212,14 @@ OC.L10N.register(
     "sunny" : "me diell",
     "Hello {name}, the weather is {weather}" : "Tungjatjeta {name}, koha është {weather}",
     "Hello {name}" : "Tungjatjeta {name}",
+    "new" : "re",
     "_download %n file_::_download %n files_" : ["shkarko %n kartelë","shkarko %n kartela"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Përmirësimi po kryhet, braktisja e kësaj faqeje mund ta ndërpresë procesin në disa mjedise.",
-    "Updating {productName} to version {version}, this may take a while." : "Po përditësohet {productName} me versionin {version}, kjo mund të zgjasë pak.",
+    "Updating to {version}" : "Po përditësohet me {version}",
     "An error occurred." : "Ndodhi një gabim.",
     "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Përditësimi qe i pasuksesshëm. Për më tepër të dhëna <a href=\"{url}\">shihni postimin te forumi ynë</a> lidhur me këtë çështje.",
-    "The update was unsuccessful. " : "Përditësimi qe i pasuksesshëm. ",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Azhurnimi dështoi. Ju lutemi njoftoni për këtë problem <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">komunitetin ownCloud</a>.",
     "The update was successful. There were warnings." : "Përditësimi qe i suksesshëm. Pati sinjalizime.",
     "The update was successful. Redirecting you to ownCloud now." : "Përditësimi qe i suksesshëm. Po ridrejtoheni te ownCloud-i.",
     "Searching other places" : "Po kërkohet në vende të tjera",
@@ -214,13 +230,6 @@ OC.L10N.register(
     "Apps" : "Aplikacione",
     "Admin" : "Admin",
     "Help" : "Ndihmë",
-    "Error loading tags" : "Gabim gjatë ngarkimit të etiketave",
-    "Tag already exists" : "Etiketa ekziston",
-    "Error deleting tag(s)" : "Gabim gjatë fshirjes së etiketës(ave)",
-    "Error tagging" : "Gabim etiketimi",
-    "Error untagging" : "Gabim në heqjen e etiketës",
-    "Error favoriting" : "Gabim në ruajtjen si të parapëlqyer",
-    "Error unfavoriting" : "Gabim në heqjen nga të parapëlqyerat",
     "Access forbidden" : "Ndalohet hyrja",
     "File not found" : "S’u gjet kartelë",
     "The specified document has not been found on the server." : "Dokumenti i përcaktuar s’u gjet në shërbyes.",
@@ -243,7 +252,7 @@ OC.L10N.register(
     "Trace" : "Gjurmim",
     "Security warning" : "Sinjalizim sigurie",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Drejtoria juaj e të dhënave dhe kartelat tuaja ka shumë mundësi të jenë të arritshme që nga interneti, ngaqë kartela .htaccess s’funksionon.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Për të dhëna se si të formësohet si duhet shërbyesi juaj, ju lutemi, shihni <a href=\"%s\" target=\"_blank\">dokumentimin</a>.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Për më tepër të dhëna se si të formësoni si duhet shërbyesin tuaj, ju lutemi, shihni <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dokumentimin</a>.",
     "Create an <strong>admin account</strong>" : "Krijoni një <strong>llogari administruesi</strong>",
     "Username" : "Emër përdoruesi",
     "Storage & database" : "Depozitë & bazë të dhënash",
@@ -271,8 +280,9 @@ OC.L10N.register(
     "Search" : "Kërko",
     "Server side authentication failed!" : "Mirëfilltësimi më anë të shërbyesit dështoi!",
     "Please contact your administrator." : "Ju lutemi, lidhuni me përgjegjësin tuaj.",
-    "An internal error occured." : "Ndodhi një gabim i brendshëm.",
+    "An internal error occurred." : "Ndodhi një gabim i brendshëm.",
     "Please try again or contact your administrator." : "Ju lutemi, riprovoni ose lidhuni me përgjegjësin tuaj.",
+    "Username or email" : "Emër përdoruesi ose email",
     "Log in" : "Hyni",
     "Wrong password. Reset it?" : "Fjalëkalim i gabuar. Të ricaktohet?",
     "Wrong password." : "Fjalëkalim i gabuar.",
@@ -286,6 +296,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Kjo do të thotë që instancën mund ta përdorin vetëm administratorët.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Nëse ky mesazh shfaqet vazhdimisht ose u shfaq papritmas, lidhuni me përgjegjësin e sistemit.",
     "Thank you for your patience." : "Ju faleminderit për durimin.",
+    "Two-step verification" : "Verifikim dyhapësh",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Siguria e zgjeruar është aktivizuar për llogarinë tuaj. Ju lutemi, bëni mirëfilltësimin duke përdorur një faktor të dytë.",
+    "Cancel login" : "Anuloje hyrjen",
+    "Please authenticate using the selected factor." : "Ju lutemi, bëni mirëfilltësimin duke përdorur faktorin e përzgjedhur.",
+    "An error occured while verifying the token" : "Ndodhi një gabim gjatë verifikimit të token-it",
     "You are accessing the server from an untrusted domain." : "Po hyni në shërbyes nga një përkatësi jo e besuar.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ju lutemi, lidhuni me përgjegjësin tuaj. Nëse jeni një përgjegjës në këtë instancë, formësoni rregullimin \"trusted_domains\" te config/config.php. Një formësim shembull jepet te config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Në varësi të formësimit tuaj, si administrator mundet gjithashtu të jeni në gjendje të përdorni butonin më poshtë për ta besuar këtë përkatësi.",
@@ -298,9 +313,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ju lutemi, para se të vazhdoni më tej, sigurohuni që baza e të dhënave, dosja e formësimeve dhe dosja e të dhënave janë kopjeruajtur.",
     "Start update" : "Fillo përditësimin",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Për të shmangur çaste bllokimi pune me instalime të mëdha, mundeni të ekzekutoni urdhrin vijues që nga drejtoria juaj e instalimit:",
+    "Detailed logs" : "Regjistrime të hollësishme",
+    "Update needed" : "Lyp përditësim",
+    "Please use the command line updater because you have a big instance." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse keni një instalim të madh.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Për ndihmë, shihni  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Kjo instancë %s hëpërhë gjendet nën mënyrën mirëmbajtje, çka mund të zgjasë ca.",
-    "This page will refresh itself when the %s instance is available again." : "Kjo faqe do të rifreskohet vetiu, sapo instanca %s të jetë sërish gati.",
-    "Error loading file picker template: {error}" : "Gabim në ngarkimin e gjedhes së marrësit të kartelave: {error}",
-    "Password can not be changed. Please contact your administrator." : "Fjalëkalimi nuk mund të ndryshohet. Ju lutemi, lidhuni me përgjegjësin tuaj."
+    "This page will refresh itself when the %s instance is available again." : "Kjo faqe do të rifreskohet vetiu, sapo instanca %s të jetë sërish gati."
 },
 "nplurals=2; plural=(n != 1);");
