@@ -1,13 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Nije bilo moguće poslati e-mail sledećim korisnicima: %s",
-    "Turned on maintenance mode" : "Uključen je režim za održavanje",
-    "Turned off maintenance mode" : "Isključen je režim za održavanje",
-    "Updated database" : "Osvežena je baza podataka",
-    "Checked database schema update" : "Provereno je osvežavanje šema baze podataka",
-    "Checked database schema update for apps" : "Provereno je osvežavanje šema baze podataka za aplikacije",
-    "Updated \"%s\" to %s" : "Osveženo je \"%s\" na \"%s\"",
     "No image or file provided" : "Nije data slika ili fajl",
     "Unknown filetype" : "Nepoznat tip fajla",
     "Invalid image" : "Neispravna slika",
@@ -17,6 +10,20 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Nije bilo moguće poslati Email za ponovno postavljanje. Molimo Vas da proverite da li je Vaše korisničko ime ispravno.",
     "%s password reset" : "%s lozinka ponovo postavljena",
     "Couldn't send reset email. Please contact your administrator." : "Nemoguće slanje e-mail-a za ponovno postavljanje lozinke. Molimo Vas kontaktirajte Vašeg administratora",
+    "Error loading tags" : "Greška pri učitavanju oznaka",
+    "Tag already exists" : "Oznaka već postoji",
+    "Error deleting tag(s)" : "Greška pri brisanju oznaka",
+    "Error tagging" : "Greška pri postavljanju oznake",
+    "Error untagging" : "Greška pri uklanjanju oznake",
+    "Error favoriting" : "Greška pri dodavanju omiljenog",
+    "Error unfavoriting" : "Greška pri uklanjanju omiljenog",
+    "Couldn't send mail to following users: %s " : "Nije bilo moguće poslati e-mail sledećim korisnicima: %s",
+    "Turned on maintenance mode" : "Uključen je režim za održavanje",
+    "Turned off maintenance mode" : "Isključen je režim za održavanje",
+    "Updated database" : "Osvežena je baza podataka",
+    "Checked database schema update" : "Provereno je osvežavanje šema baze podataka",
+    "Checked database schema update for apps" : "Provereno je osvežavanje šema baze podataka za aplikacije",
+    "Updated \"%s\" to %s" : "Osveženo je \"%s\" na \"%s\"",
     "Sunday" : "Nedelja",
     "Monday" : "Ponedeljak",
     "Tuesday" : "Utorak",
@@ -97,8 +104,6 @@ OC.L10N.register(
     "Expiration" : "Isticanje",
     "Expiration date" : "Datum isteka",
     "Choose a password for the public link" : "Izaberite lozinku za javnu prečicu",
-    "Sending ..." : "Slanje...",
-    "Email sent" : "Email poslat",
     "Resharing is not allowed" : "Dalje deljenje nije dozvoljeno",
     "Share link" : "Podeli prečicu",
     "Link" : "Prečica",
@@ -107,6 +112,8 @@ OC.L10N.register(
     "Allow editing" : "Dozvoli uređivanje",
     "Email link to person" : "Pošalji link e-mailom",
     "Send" : "Pošalji",
+    "Sending ..." : "Slanje...",
+    "Email sent" : "Email poslat",
     "Shared with you and the group {group} by {owner}" : "{owner} podelio sa Vama i grupom {group} ",
     "Shared with you by {owner}" : "Sa vama podelio {owner}",
     "group" : "grupa",
@@ -134,22 +141,14 @@ OC.L10N.register(
     "sunny" : "sunčano",
     "Hello {name}, the weather is {weather}" : "Zdravo {name}, vreme je {weather}",
     "_download %n file_::_download %n files_" : ["Preuzmi %n fajl","Preuzmi %n fajlova","Preuzmi %n fajlova"],
-    "Updating {productName} to version {version}, this may take a while." : "Osvežavam {productName} na verziju {version}, ovo može potrajati.",
     "Please reload the page." : "Molimo, ponovo učitajte stranu.",
-    "The update was unsuccessful. " : "Osvežavanje je uspelo.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Ažuriranje nije uspelo. Molimo obavestite <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud zajednicu</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspelo. Prosleđivanje na ownCloud.",
     "Personal" : "Lično",
     "Users" : "Korisnici",
     "Apps" : "Programi",
     "Admin" : "Adninistracija",
     "Help" : "Pomoć",
-    "Error loading tags" : "Greška pri učitavanju oznaka",
-    "Tag already exists" : "Oznaka već postoji",
-    "Error deleting tag(s)" : "Greška pri brisanju oznaka",
-    "Error tagging" : "Greška pri postavljanju oznake",
-    "Error untagging" : "Greška pri uklanjanju oznake",
-    "Error favoriting" : "Greška pri dodavanju omiljenog",
-    "Error unfavoriting" : "Greška pri uklanjanju omiljenog",
     "Access forbidden" : "Pristup zabranjen",
     "File not found" : "Fajl nije nađen",
     "The specified document has not been found on the server." : "Traženi dokument nije nađen na serveru.",
@@ -170,7 +169,6 @@ OC.L10N.register(
     "Line: %s" : "Linija: %s",
     "Trace" : "Zapisnik: ",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vaši podaci i direktorijumi su verovatno dostupni sa interneta jer .htaccess fajl ne funkcioniše.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Za informacije kako da pravilno podesite server, molimo Vas da pogledate <a href=\"%s\" target=\"_blank\">dokumentaciju</a>.",
     "Create an <strong>admin account</strong>" : "Napravi <strong>administrativni nalog</strong>",
     "Username" : "Korisničko ime",
     "Storage & database" : "Skladište i baza podataka",
