@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "无法发送邮件到用户: %s ",
-    "Preparing update" : "正在准备更新",
-    "Turned on maintenance mode" : "启用维护模式",
-    "Turned off maintenance mode" : "关闭维护模式",
-    "Maintenance mode is kept active" : "维护模式已被启用",
-    "Updating database schema" : "正在更新数据库架构",
-    "Updated database" : "数据库已更新",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "检查数据库架构是否可以更新 (这可能需要很长的时间，这取决于数据库大小)",
-    "Checked database schema update" : "已经检查数据库架构更新",
-    "Checking updates of apps" : "检查更新应用",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "检查 %s 的数据库架构是否可以更新 (这可能需要很长的时间，这取决于数据库大小)",
-    "Checked database schema update for apps" : "已经检查应用的数据库架构更新",
-    "Updated \"%s\" to %s" : "更新 \"%s\" 为 %s",
-    "Repair warning: " : "修复警告：",
-    "Repair error: " : "修复错误：",
-    "Set log level to debug" : "设置日志级别为 调试",
-    "Reset log level" : "重设日志级别",
-    "Starting code integrity check" : "开始代码完整性检查",
-    "Finished code integrity check" : "代码完整性检查完成",
-    "%s (3rdparty)" : "%s (第三方)",
-    "%s (incompatible)" : "%s (不兼容)",
-    "Following apps have been disabled: %s" : "下列应用已经被禁用：%s",
-    "Already up to date" : "已经是最新",
     "Please select a file." : "请选择一个文件",
     "File is too big" : "文件太大",
     "Invalid file provided" : "提供了无效文件",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "此用户名的电子邮件地址不存在导致无法发送重置邮件，请联系管理员。",
     "%s password reset" : "重置 %s 的密码",
     "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
+    "Error loading tags" : "加载标签出错",
+    "Tag already exists" : "标签已存在",
+    "Error deleting tag(s)" : "删除标签时出错",
+    "Error tagging" : "增加标签时出错",
+    "Error untagging" : "移除标签时出错",
+    "Error favoriting" : "收藏时出错",
+    "Error unfavoriting" : "删除收藏时出错",
+    "Couldn't send mail to following users: %s " : "无法发送邮件到用户: %s ",
+    "Preparing update" : "正在准备更新",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "修复警告：",
+    "Repair error: " : "修复错误：",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "由于自动更新在 config.php 中已禁用，请使用命令行更新。",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: 检查数据表 %s",
+    "Turned on maintenance mode" : "启用维护模式",
+    "Turned off maintenance mode" : "关闭维护模式",
+    "Maintenance mode is kept active" : "维护模式已被启用",
+    "Updating database schema" : "正在更新数据库架构",
+    "Updated database" : "数据库已更新",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "检查数据库架构是否可以更新 (这可能需要很长的时间，这取决于数据库大小)",
+    "Checked database schema update" : "已经检查数据库架构更新",
+    "Checking updates of apps" : "检查更新应用",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "检查 %s 的数据库架构是否可以更新 (这可能需要很长的时间，这取决于数据库大小)",
+    "Checked database schema update for apps" : "已经检查应用的数据库架构更新",
+    "Updated \"%s\" to %s" : "更新 \"%s\" 为 %s",
+    "Set log level to debug" : "设置日志级别为 调试",
+    "Reset log level" : "重设日志级别",
+    "Starting code integrity check" : "开始代码完整性检查",
+    "Finished code integrity check" : "代码完整性检查完成",
+    "%s (3rdparty)" : "%s (第三方)",
+    "%s (incompatible)" : "%s (不兼容)",
+    "Following apps have been disabled: %s" : "下列应用已经被禁用：%s",
+    "Already up to date" : "已经是最新",
     "Sunday" : "星期日",
     "Monday" : "星期一",
     "Tuesday" : "星期二",
@@ -88,6 +98,7 @@ OC.L10N.register(
     "Dec." : "十二月",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">代码完整性检查出现异常，点击查看详细信息...</a>",
     "Settings" : "设置",
+    "Problem loading page, reloading in 5 seconds" : "加载页面出现问题，在 5 秒内重新载入",
     "Saving..." : "保存中...",
     "Dismiss" : "忽略",
     "seconds ago" : "几秒前",
@@ -119,11 +130,18 @@ OC.L10N.register(
     "Good password" : "较强的密码",
     "Strong password" : "强密码",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "由于 WebDAV 接口似乎被破坏，因此你的网页服务器没有正确地设置来允许文件同步。",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "您的web服务器未正确设置以解析 \"{url}\"。您可以在我们的<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>中找到更多可用信息。",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "此服务器上没有可用的因特网连接. 这意味着某些特性将无法工作，例如挂载外部存储器, 提醒更新或安装第三方应用等. 从远程访问文件和发送提醒电子邮件也可能无法工作. 如果你想要ownCloud的所有特性, 我们建议启用此服务器的因特网连接.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "内存缓存未配置。如果可用，请配置 memcache 来增强性能。更多信息请查看我们的<a target=\"_blank\" href=\"{docLink}\">文档</a> 。",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "内存缓存未配置。如果可用，请配置 memcache 来增强性能。更多信息请查看我们的<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a> 。",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom 无法被 PHP 读取，出于安全原因，这是强烈不推荐的。请查看<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>了解详情。",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "你的 PHP 版本 ({version}) 不再被 <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\"> PHP </a>支持。我们建议您升级您的PHP版本，以便获得 PHP 性能和安全提升。",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "反向代理头配置不正确，或者您正从一个受信任的代理访问ownCloud。如果你不是通过受信任的代理访问 ownCloud，这将引发一个安全问题，可能由于 ownCloud IP 地址可见导致欺骗攻击。更多信息可以查看我们的 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>。",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached 配置为分布式缓存，但是已经安装的 PHP 模块是 \"memcache\" 。 \\OC\\Memcache\\Memcached 仅支持 \"memcached\" 而不是 \"memcache\"。点击 <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\"> memcached wiki 了解两个模块的不同</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "一些文件没有通过完整性检查。如何解决此问题的详细信息可以查看我们的 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">无效文件列表…</a> / <a href=\"{rescanEndpoint}\">重新扫描…</a>)",
     "Error occurred while checking server setup" : "当检查服务器启动时出错",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "你的数据目录和你的文件可能从互联网被访问到。.htaccess 文件不工作。我们强烈建议你配置你的网页服务器，使数据目录不再可访问，或者将数据目录移动到网页服务器根文档目录之外。",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 头部没有配置和 \"{expected}\" 的一样。这是一个潜在的安全或者隐私风险，我们调整这项设置。",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP 严格传输安全（Strict-Transport-Security）报头未配置到至少“{seconds}”秒。处于增强安全性考虑，我们推荐按照<a href=\"{docUrl}\" rel=\"noreferrer\">安全提示</a>启用 HSTS。",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "您正在通过 HTTP 访问该站点，我们强烈建议您按照<a href=\"{docUrl}\">安全提示</a>配置服务器强制使用 HTTPS。",
     "Shared" : "已共享",
     "Shared with {recipients}" : "由{recipients}分享",
@@ -136,8 +154,6 @@ OC.L10N.register(
     "Expiration" : "过期",
     "Expiration date" : "过期日期",
     "Choose a password for the public link" : "为共享链接设置密码",
-    "Sending ..." : "正在发送...",
-    "Email sent" : "邮件已发送",
     "Resharing is not allowed" : "不允许二次共享",
     "Share link" : "分享链接",
     "Link" : "链接",
@@ -146,6 +162,9 @@ OC.L10N.register(
     "Allow editing" : "允许编辑",
     "Email link to person" : "发送链接到个人",
     "Send" : "发送",
+    "Sending ..." : "正在发送...",
+    "Email sent" : "邮件已发送",
+    "Send link via email" : "通过邮件发送链接",
     "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 组",
     "Shared with you by {owner}" : "{owner} 与您共享",
     "group" : "群组",
@@ -161,23 +180,27 @@ OC.L10N.register(
     "Could not unshare" : "无法共享",
     "Share details could not be loaded for this item." : "无法加载这个项目的分享详情",
     "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
-    "An error occured. Please try again" : "发生了一个错误请重新尝试",
+    "No users found for {search}" : "没有找到 {search} 用户",
+    "An error occurred. Please try again" : "发生错误。请重试。",
     "{sharee} (group)" : "{sharee} (组)",
     "{sharee} (at {server})" : "{sharee} (位于 {server})",
     "{sharee} (remote)" : "{sharee} (远程)",
     "Share" : "分享",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "使用语法 username@example.com/owncloud 分享给其他 ownCloud 上的用户",
-    "Share with users or groups …" : "分享给其他用户或组 ...",
-    "Share with users, groups or remote users …" : "分享给其他用户、组或远程用户 ...",
+    "Share with users…" : "与用户分享...",
+    "Share with users, groups or remote users…" : "与用户，组或远程用户分享...",
+    "Share with users or groups…" : "与用户或组分享...",
+    "Share with users or remote users…" : "与用户或远程用户分享...",
     "Error removing share" : "移除分享时出错",
     "Warning" : "警告",
     "Error while sending notification" : "发送通知时出现错误",
     "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
-    "not assignable" : "不可分配",
+    "restricted" : "受限",
     "invisible" : "不可见",
     "({scope})" : "({scope})",
     "Delete" : "删除",
     "Rename" : "重命名",
+    "Collaborative tags" : "协作标签",
     "The object type is not specified." : "未指定对象类型。",
     "Enter new" : "输入新...",
     "Add" : "增加",
@@ -189,12 +212,14 @@ OC.L10N.register(
     "sunny" : "晴",
     "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是{weather}",
     "Hello {name}" : "你好 {name}",
+    "new" : "新建",
     "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "升级正在进行，在某些环境中离开此网页可能中断该过程。",
-    "Updating {productName} to version {version}, this may take a while." : "更新 {productName} 到版本 {version}，这可能需要一些时间。",
+    "Updating to {version}" : "正在升级到 {version}",
     "An error occurred." : "发生了一个错误",
     "Please reload the page." : "请重新加载页面。",
-    "The update was unsuccessful. " : "升级未成功",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新不成功。有关此问题的更多信息请<a href=\"{url}\">查看我们的论坛帖子</a>。",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "更新不成功。请汇报将此问题汇报给  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud 社区</a>。",
     "The update was successful. There were warnings." : "更新成功。有警告。",
     "The update was successful. Redirecting you to ownCloud now." : "更新成功。正在重定向至 ownCloud。",
     "Searching other places" : "搜索其他地方",
@@ -205,13 +230,6 @@ OC.L10N.register(
     "Apps" : "应用",
     "Admin" : "管理",
     "Help" : "帮助",
-    "Error loading tags" : "加载标签出错",
-    "Tag already exists" : "标签已存在",
-    "Error deleting tag(s)" : "删除标签时出错",
-    "Error tagging" : "增加标签时出错",
-    "Error untagging" : "移除标签时出错",
-    "Error favoriting" : "收藏时出错",
-    "Error unfavoriting" : "删除收藏时出错",
     "Access forbidden" : "访问禁止",
     "File not found" : "文件未找到",
     "The specified document has not been found on the server." : "在服务器上没找到指定的文件。",
@@ -234,7 +252,7 @@ OC.L10N.register(
     "Trace" : "追踪",
     "Security warning" : "安全警告",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的数据目录和文件可能可以直接被互联网访问，因为 .htaccess 并未正常工作。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "关于如何配置服务器，请参见 <a href=\"%s\" target=\"_blank\">此文档</a>。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "关于如何正确配置服务器，请参见 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">此文档</a>.。",
     "Create an <strong>admin account</strong>" : "创建<strong>管理员账号</strong>",
     "Username" : "用户名",
     "Storage & database" : "存储 & 数据库",
@@ -262,8 +280,9 @@ OC.L10N.register(
     "Search" : "搜索",
     "Server side authentication failed!" : "服务端验证失败！",
     "Please contact your administrator." : "请联系你的管理员。",
-    "An internal error occured." : "发生了内部错误。",
+    "An internal error occurred." : "发生了内部错误。",
     "Please try again or contact your administrator." : "请重试或联系管理员。",
+    "Username or email" : "用户名或邮箱",
     "Log in" : "登录",
     "Wrong password. Reset it?" : "密码错误。要重置么？",
     "Wrong password." : "密码错误",
@@ -277,6 +296,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "这意味着只有管理员才能在实例上操作。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系你的系统管理员。",
     "Thank you for your patience." : "感谢让你久等了。",
+    "Two-step verification" : "两步验证",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "您的帐户已启用增强安全性，请使用第二因子验证。",
+    "Cancel login" : "取消登录",
+    "Please authenticate using the selected factor." : "请使用所选择的因素验证。",
+    "An error occured while verifying the token" : "在验证令牌时出错",
     "You are accessing the server from an untrusted domain." : "您正在访问来自不信任域名的服务器。",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "请联系你的系统管理员。如果你是系统管理员，配置 config/config.php 文件中参数 \"trusted_domain\" 设置。可以在 config/config.sample.php 文件中找到例子。",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "基于你的配置，作为系统管理员，你可能还能点击下面的按钮来信任这个域。",
@@ -289,10 +313,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在继续之前，请确认数据库、配置文件夹和数据文件夹已经备份。",
     "Start update" : "开始更新",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为进行避免较大的安装时超时，你可以在你的安装目录下运行下面的命令：",
+    "Detailed logs" : "详细日志",
+    "Update needed" : "需要更新",
+    "Please use the command line updater because you have a big instance." : "请使用命令行更新。",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "该 %s 实例当前处于维护模式，这将进行一些时间。",
-    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。",
-    "Collaborative tags" : "协作标签",
-    "Error loading file picker template: {error}" : "加载文件分拣模板出错: {error}",
-    "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。"
+    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。"
 },
 "nplurals=1; plural=0;");
