@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "無法寄送郵件給這些使用者：%s",
-    "Preparing update" : "準備更新",
-    "Turned on maintenance mode" : "已啓用維護模式",
-    "Turned off maintenance mode" : "已停用維護模式",
-    "Maintenance mode is kept active" : "維護模式維持在開啟狀態",
-    "Updating database schema" : "更新資料庫格式",
-    "Updated database" : "已更新資料庫",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "檢查是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
-    "Checked database schema update" : "已檢查資料庫格式更新",
-    "Checking updates of apps" : "檢查 app 更新",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
-    "Checked database schema update for apps" : "已檢查應用程式的資料庫格式更新",
-    "Updated \"%s\" to %s" : "已更新 %s 到 %s",
-    "Repair warning: " : "修復警告：",
-    "Repair error: " : "修復錯誤",
-    "Set log level to debug" : "設定紀錄變成除錯層級",
-    "Reset log level" : "重設記錄層級",
-    "Starting code integrity check" : "開始檢查程式碼完整性",
-    "Finished code integrity check" : "完成程式碼完整性檢查",
-    "%s (3rdparty)" : "%s (第3方)",
-    "%s (incompatible)" : "%s (不相容的)",
-    "Following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
-    "Already up to date" : "已經是最新版",
     "Please select a file." : "請選擇一個檔案",
     "File is too big" : "檔案太大",
     "Invalid file provided" : "提供的檔案無效",
@@ -41,6 +18,36 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "無法寄送重設 email ，因為這個帳號沒有設定 email 地址，請聯絡您的系統管理員。",
     "%s password reset" : "%s 密碼重設",
     "Couldn't send reset email. Please contact your administrator." : "無法寄送重設 email ，請聯絡系統管理員",
+    "Error loading tags" : "載入標籤出錯",
+    "Tag already exists" : "標籤已經存在",
+    "Error deleting tag(s)" : "刪除標籤出錯",
+    "Error tagging" : "貼標籤發生錯誤",
+    "Error untagging" : "移除標籤失敗",
+    "Error favoriting" : "加入最愛時出錯",
+    "Error unfavoriting" : "從最愛移除出錯",
+    "Couldn't send mail to following users: %s " : "無法寄送郵件給這些使用者：%s",
+    "Preparing update" : "準備更新",
+    "Repair warning: " : "修復警告：",
+    "Repair error: " : "修復錯誤",
+    "Turned on maintenance mode" : "已啓用維護模式",
+    "Turned off maintenance mode" : "已停用維護模式",
+    "Maintenance mode is kept active" : "維護模式維持在開啟狀態",
+    "Updating database schema" : "更新資料庫格式",
+    "Updated database" : "已更新資料庫",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "檢查是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
+    "Checked database schema update" : "已檢查資料庫格式更新",
+    "Checking updates of apps" : "檢查 app 更新",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
+    "Checked database schema update for apps" : "已檢查應用程式的資料庫格式更新",
+    "Updated \"%s\" to %s" : "已更新 %s 到 %s",
+    "Set log level to debug" : "設定紀錄變成除錯層級",
+    "Reset log level" : "重設記錄層級",
+    "Starting code integrity check" : "開始檢查程式碼完整性",
+    "Finished code integrity check" : "完成程式碼完整性檢查",
+    "%s (3rdparty)" : "%s (第3方)",
+    "%s (incompatible)" : "%s (不相容的)",
+    "Following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
+    "Already up to date" : "已經是最新版",
     "Sunday" : "週日",
     "Monday" : "週一",
     "Tuesday" : "週二",
@@ -118,14 +125,7 @@ OC.L10N.register(
     "Good password" : "密碼強度佳",
     "Strong password" : "密碼強度極佳",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "您的網頁伺服器無法提供檔案同步功能，因為 WebDAV 界面有問題",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "您的網路伺服器尚未妥善的設定\"{url}\"。更多資訊請參閱我們的 <a target=\"_blank\" href=\"{docLink}\">文件</a>。",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "伺服器沒有網際網路連線，有些功能，像是外部儲存、更新版通知將無法運作。從遠端存取資料或是寄送 email 通知可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "沒有設定 memory cache，為了增加效能，可以設定一個 memory cache ，請到<a target=\"_blank\" href=\"{docLink}\">我們的文件</a>取得更多資訊",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom 無法被 PHP 讀取，將造成安全性風險，請到<a target=\"_blank\" href=\"{docLink}\">我們的文件</a>取得更多資訊",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "您的PHP版本 ({version}) 不再被<a href=\"{phpLink}\">PHP</a>支援，我們建議您升級您的PHP版本來提升效能以及安全性。",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "反向代理伺服器標頭配置不正確或者您正從一個受信任的代理伺服器訪問ownCloud，如果您不是從受信任的代理伺服器訪問ownCloud，表示這是一個安全性問題，攻擊者可利用IP詐騙存取ownCloud，更多訊息查看 <a href=\"{docLink}\">文件</a>。",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached 被設置成分散式緩存模式，但已經安裝了錯誤的PHP模組 \"memcache\"。\\OC\\Memcache\\Memcached 只支援 \"memcached\"，並未支援\"memcache\"。請參閱<a target=\"_blank\" href=\"{wikiLink}\">關於這兩個模組的wiki</a>。",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "有些檔案並未通過程式碼完整性的檢查，更多有關如何解決上述問題的資訊請參閱我們的 <a target=\"_blank\" href=\"{docLink}\">文件</a>。(<a href=\"{codeIntegrityDownloadEndpoint}\">列出所有無效的檔案…</a> / <a href=\"{rescanEndpoint}\">重新掃描…</a>)",
     "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "您的資料目錄和您的檔案可能從網路網路被存取，使.htaccess 檔案無法發揮效果，我們強烈建議您配置您的網頁伺服器讓資料目錄不再被訪問存取或者將您的資料目錄移出網頁伺服器根目錄。",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 標頭配置與 \"{expected}\"不一樣，這是一個潛在安全性或者隱私上的風險，因此我們建議您調整此設定",
@@ -141,8 +141,6 @@ OC.L10N.register(
     "Expiration" : "過期",
     "Expiration date" : "到期日",
     "Choose a password for the public link" : "為公開連結選一個密碼",
-    "Sending ..." : "正在傳送…",
-    "Email sent" : "Email 已寄出",
     "Resharing is not allowed" : "不允許重新分享",
     "Share link" : "分享連結",
     "Link" : "連結",
@@ -151,6 +149,8 @@ OC.L10N.register(
     "Allow editing" : "允許編輯",
     "Email link to person" : "將連結 email 給別人",
     "Send" : "寄出",
+    "Sending ..." : "正在傳送…",
+    "Email sent" : "Email 已寄出",
     "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}",
     "Shared with you by {owner}" : "{owner} 已經和您分享",
     "group" : "群組",
@@ -163,16 +163,28 @@ OC.L10N.register(
     "change" : "更動",
     "delete" : "刪除",
     "access control" : "存取控制",
+    "Could not unshare" : "無法取消分享",
     "Share details could not be loaded for this item." : "無法載入分享細節",
-    "An error occured. Please try again" : "發生錯誤，請重試",
+    "No users or groups found for {search}" : "沒有群組或使用者符合 {search}",
+    "No users found for {search}" : "沒有使用者符合 {search}",
+    "{sharee} (group)" : "{sharee} （群組）",
+    "{sharee} (at {server})" : "{sharee} （在 {server}）",
+    "{sharee} (remote)" : "{sharee} （遠端）",
     "Share" : "分享",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "與其他在ownCloud上的人們分享，請使用此格式 username@example.com/owncloud",
-    "Share with users or groups …" : "與用戶或群組分享 ...",
-    "Share with users, groups or remote users …" : "與用戶，群組或是遠端使用者分享 ...",
+    "Share with users…" : "分享給其他使用者…",
+    "Share with users, groups or remote users…" : "分享給其他使用者、群組或遠端使用者…",
+    "Share with users or groups…" : "分享給群組或使用者…",
+    "Share with users or remote users…" : "分享給使用者或遠端使用者…",
+    "Error removing share" : "移除分享時發生錯誤",
     "Warning" : "警告",
     "Error while sending notification" : "發送通知錯誤",
+    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
+    "invisible" : "不可見",
+    "({scope})" : "（{scope}）",
     "Delete" : "刪除",
     "Rename" : "重新命名",
+    "Collaborative tags" : "標籤",
     "The object type is not specified." : "未指定物件類型",
     "Enter new" : "輸入新的",
     "Add" : "增加",
@@ -184,12 +196,13 @@ OC.L10N.register(
     "sunny" : "晴朗的",
     "Hello {name}, the weather is {weather}" : "哈囉 {name}, 天氣是 {weather}",
     "Hello {name}" : "哈囉 {name}",
+    "new" : "新",
     "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
-    "Updating {productName} to version {version}, this may take a while." : "正在更新 {productName} 到版本 {version} ，請稍候",
     "An error occurred." : "發生錯誤",
     "Please reload the page." : "請重新整理頁面",
-    "The update was unsuccessful. " : "更新失敗",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗，檢視<a href=\"{url}\">論壇上的文章</a>來瞭解更多",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "升級失敗，請將此問題回報 <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud 社群</a>。",
     "The update was successful. There were warnings." : "更新成功，有警告訊息",
     "The update was successful. Redirecting you to ownCloud now." : "升級成功，正將您重新導向至 ownCloud 。",
     "Searching other places" : "搜尋其他位置",
@@ -200,13 +213,6 @@ OC.L10N.register(
     "Apps" : "應用程式",
     "Admin" : "管理",
     "Help" : "說明",
-    "Error loading tags" : "載入標籤出錯",
-    "Tag already exists" : "標籤已經存在",
-    "Error deleting tag(s)" : "刪除標籤出錯",
-    "Error tagging" : "貼標籤發生錯誤",
-    "Error untagging" : "移除標籤失敗",
-    "Error favoriting" : "加入最愛時出錯",
-    "Error unfavoriting" : "從最愛移除出錯",
     "Access forbidden" : "存取被拒",
     "File not found" : "找不到檔案",
     "The specified document has not been found on the server." : "該文件不存在於伺服器上",
@@ -229,7 +235,6 @@ OC.L10N.register(
     "Trace" : "追蹤",
     "Security warning" : "安全性警告",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄看起來可以被 Internet 公開存取，因為 .htaccess 設定並未生效。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "請參考<a href=\"%s\" target=\"_blank\">說明文件</a>以瞭解如何正確設定您的伺服器。",
     "Create an <strong>admin account</strong>" : "建立一個<strong>管理者帳號</strong>",
     "Username" : "使用者名稱",
     "Storage & database" : "儲存空間和資料庫",
@@ -257,7 +262,6 @@ OC.L10N.register(
     "Search" : "搜尋",
     "Server side authentication failed!" : "伺服器端認證失敗！",
     "Please contact your administrator." : "請聯絡系統管理員",
-    "An internal error occured." : "發生內部錯誤",
     "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
     "Log in" : "登入",
     "Wrong password. Reset it?" : "密碼錯誤，重設密碼？",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Start update" : "開始升級",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在大型安裝上，為了避免升級請求逾時，你也可以在安裝目錄執行下列指令：",
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，需要一段時間恢復。",
-    "This page will refresh itself when the %s instance is available again." : "%s 安裝恢復可用之後，本頁會自動重新整理",
-    "Error loading file picker template: {error}" : "載入檔案選擇器樣板出錯： {error}",
-    "Password can not be changed. Please contact your administrator." : "無法變更密碼，請聯絡您的系統管理員"
+    "This page will refresh itself when the %s instance is available again." : "%s 安裝恢復可用之後，本頁會自動重新整理"
 },
 "nplurals=1; plural=0;");
