@@ -5,11 +5,6 @@ OC.L10N.register(
     "This can usually be fixed by giving the webserver write access to the config directory" : "Generalmente esto se puede resolver otorgando permisos de escritura al servidor web en la carpeta configurada",
     "See %s" : "Ver %s",
     "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Generalmente esto se puede resolver %s otorgando permisos de escritura al servidor web en la carpeta configurada %s",
-    "Help" : "Ayuda",
-    "Personal" : "Personal",
-    "Users" : "Usuarios",
-    "Admin" : "Administración",
-    "No app name specified" : "No se especificó el nombre de la aplicación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen no válida",
     "today" : "hoy",
@@ -17,9 +12,14 @@ OC.L10N.register(
     "last month" : "mes anterior",
     "last year" : "último año",
     "seconds ago" : "segundos antes",
-    "web services under your control" : "Servicios Web bajo su control",
     "App directory already exists" : "El directorio de la aplicación ya existe",
     "Can't create app folder. Please fix permissions. %s" : "No se puede crear el directorio de aplicación. Por favor corregir los permisos. %s",
-    "No source specified when installing app" : "No se especificó el origen al instalar la aplicación"
+    "No source specified when installing app" : "No se especificó el origen al instalar la aplicación",
+    "Help" : "Ayuda",
+    "Personal" : "Personal",
+    "Users" : "Usuarios",
+    "Admin" : "Administración",
+    "No app name specified" : "No se especificó el nombre de la aplicación",
+    "web services under your control" : "Servicios Web bajo su control"
 },
 "nplurals=2; plural=(n != 1);");
