@@ -17,14 +17,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
     "ownCloud %s or higher is required." : "Requírese ownCloud %s ou superior.",
     "ownCloud %s or lower is required." : "Requírese ownCloud %s ou inferior.",
-    "Help" : "Axuda",
-    "Personal" : "Persoal",
-    "Users" : "Usuarios",
-    "Admin" : "Administración",
-    "Recommended" : "Recomendado",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Non é posíbel instalar a aplicación «%s» por non seren compatíbel con esta versión do ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Non é posíbel instalar a aplicación «%s» por mor de non cumprirse as dependencias: %s",
-    "No app name specified" : "Non se especificou o nome da aplicación",
     "Unknown filetype" : "Tipo de ficheiro descoñecido",
     "Invalid image" : "Imaxe incorrecta",
     "today" : "hoxe",
@@ -37,7 +29,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
     "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
     "seconds ago" : "segundos atrás",
-    "web services under your control" : "servizos web baixo o seu control",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte co administrador.",
     "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
     "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
@@ -45,8 +36,6 @@ OC.L10N.register(
     "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
     "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
     "File name is too long" : "O nome de ficheiro é longo de máis",
-    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, tenteo máis tarde.",
-    "Can't read file" : "Non é posíbel ler o ficheiro",
     "App directory already exists" : "Xa existe o directorio da aplicación",
     "Can't create app folder. Please fix permissions. %s" : "Non é posíbel crear o cartafol de aplicacións. Corrixa os permisos. %s",
     "No source specified when installing app" : "Non foi especificada ningunha orixe ao instalar a aplicación",
@@ -58,10 +47,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Non é posíbel instalar a aplicación por mor de conter código non permitido",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Non é posíbel instalar a aplicación por non seren compatíbel  con esta versión do ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Non é posíbel instalar a aplicación por conter a etiqueta <shipped>true</shipped> que non está permitida para as aplicacións non enviadas",
-    "Application is not enabled" : "A aplicación non está activada",
-    "Authentication error" : "Produciuse un erro de autenticación",
-    "Token expired. Please reload page." : "Testemuña caducada. Recargue a páxina.",
-    "Unknown user" : "Usuario descoñecido",
     "%s enter the database username." : "%s introduza o nome de usuario da base de datos",
     "%s enter the database name." : "%s introduza o nome da base de datos",
     "%s you may not use dots in the database name" : "%s non se poden empregar puntos na base de datos",
@@ -92,6 +77,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Fallou a compartición de %s, %s non é membro do grupo %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Ten que fornecer un contrasinal para a ligazón pública, só se permiten ligazóns protexidas",
     "Sharing %s failed, because sharing with links is not allowed" : "Fallou a compartición de %s, non está permitido compartir con ligazóns",
+    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
     "Share type %s is not valid for %s" : "Non se admite a compartición do tipo %s para %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Non é posíbel estabelecer permisos para %s, os permisos superan os permisos concedidos a %s",
@@ -111,6 +97,21 @@ OC.L10N.register(
     "A valid username must be provided" : "Debe fornecer un nome de usuario",
     "A valid password must be provided" : "Debe fornecer un contrasinal",
     "The username is already being used" : "Este nome de usuario xa está a ser usado",
+    "Help" : "Axuda",
+    "Personal" : "Persoal",
+    "Users" : "Usuarios",
+    "Admin" : "Administración",
+    "Recommended" : "Recomendado",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Non é posíbel instalar a aplicación «%s» por non seren compatíbel con esta versión do ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Non é posíbel instalar a aplicación «%s» por mor de non cumprirse as dependencias: %s",
+    "No app name specified" : "Non se especificou o nome da aplicación",
+    "web services under your control" : "servizos web baixo o seu control",
+    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, tenteo máis tarde.",
+    "Can't read file" : "Non é posíbel ler o ficheiro",
+    "Application is not enabled" : "A aplicación non está activada",
+    "Authentication error" : "Produciuse un erro de autenticación",
+    "Token expired. Please reload page." : "Testemuña caducada. Recargue a páxina.",
+    "Unknown user" : "Usuario descoñecido",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hay controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
     "Microsoft Windows Platform is not supported" : "A plataforma Windows de Microsoft non é compatíbel",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Non é posíbel a execución dun servidor ownCloud na plataforma Microsoft Windows. Se non ten a opción de migrar o propio servidor, suxerímoslle que empregue un servidor Linux nunha máquina virtual. Pode atopar paquetes de Linux, así como imaxes de máquinas virtuais doadas de instalar en <a href=\"%s\">%s</a>. Para a migración das instalacións existentes cara Linux pode atopar algúns consellos e un script de migración na <a href=\"%s\">nosa documentación</a>.",
@@ -118,7 +119,6 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Non é posíbel escribir no directorio «apps»",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «apps»%s ou a desactivación da «appstore» no ficheiro de configuración.",
     "Cannot create \"data\" directory (%s)" : "Non é posíbel crear o directorio «data» (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Polo xeral, isto pode ser fixado para <a href=\"%s\" target=\"_blank\">permitirlle ao servidor web acceso de escritura  ao directorio «root»</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «root»%s.",
     "Setting locale to %s failed" : "Fallou o axuste da configuración local a %s",
     "Please install one of these locales on your system and restart your webserver." : "Instale unha destas configuracións locais no seu sistema e reinicie o servidor web.",
