@@ -9,17 +9,15 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik a példakonfigurációt próbálja ténylegesen használni. Ez nem támogatott, és működésképtelenné teheti a telepítést. Kérjük olvassa el a dokumentációt és azt követően változtasson a config.php-n!",
     "PHP %s or higher is required." : "PHP %s vagy ennél újabb szükséges.",
     "PHP with a version lower than %s is required." : "Ennél régebbi PHP szükséges: %s.",
-    "Following databases are supported: %s" : "A következő adatbázis nem támogatott: %s",
+    "%sbit or higher PHP required." : "%sbit vagy ennél magasabb szükséges.",
+    "Following databases are supported: %s" : "A következő adatbázisok támogatottak: %s",
+    "The command line tool %s could not be found" : "A parancssori eszköz %s nem található",
     "The library %s is not available." : "A könyvtár %s nem áll rendelkezésre.",
+    "Library %s with a version higher than %s is required - available version %s." : "A könyvtár a %s verzióval nagyobb mint a szükséges %s - elérhető verzió %s",
+    "Library %s with a version lower than %s is required - available version %s." : "A könyvtár a %s verzióval alacsonyabb mint a szükséges %s - elérhető verzió %s",
     "Following platforms are supported: %s" : "Ezek a platformok támogatottak: %s",
     "ownCloud %s or higher is required." : "ownCoud %s vagy ennél újabb szükséges.",
     "ownCloud %s or lower is required." : "ownCoud %s vagy ennél régebbi szükséges.",
-    "Help" : "Súgó",
-    "Personal" : "Személyes",
-    "Users" : "Felhasználók",
-    "Admin" : "Adminsztráció",
-    "Recommended" : "Ajánlott",
-    "No app name specified" : "Nincs az alkalmazás név megadva.",
     "Unknown filetype" : "Ismeretlen file tipús",
     "Invalid image" : "Hibás kép",
     "today" : "ma",
@@ -32,30 +30,29 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n órája","%n órája"],
     "_%n minute ago_::_%n minutes ago_" : ["%n perce","%n perce"],
     "seconds ago" : "pár másodperce",
-    "web services under your control" : "webszolgáltatások saját kézben",
+    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "A modul ezzel az azonosítóval:%s nem létezik. Engedélyezd az alkalmazás beállításainál vagy vedd fel a kapcsolatot az adminisztártododdal.",
     "Empty filename is not allowed" : "Üres fájlnév nem engedétlyezett",
     "Dot files are not allowed" : "Pontozott fájlok nem engedétlyezettek",
     "4-byte characters are not supported in file names" : "4-byte karakterek nem támogatottak a fájl nevekben.",
     "File name is a reserved word" : "A fajl neve egy rezervált szó",
     "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz!",
     "File name is too long" : "A fájlnév túl hosszú!",
-    "File is currently busy, please try again later" : "A fájl jelenleg elfoglalt, kérjük próbáld újra később!",
-    "Can't read file" : "Nem olvasható a fájl",
     "App directory already exists" : "Az alkalmazás mappája már létezik",
     "Can't create app folder. Please fix permissions. %s" : "Nem lehetett létrehozni az alkalmazás mappáját. Kérem ellenőrizze a jogosultságokat. %s",
+    "Archive does not contain a directory named %s" : "Az arhívum nem tartalmaz könyvátrat ezzel a névvel %s",
     "No source specified when installing app" : "Az alkalmazás telepítéséhez nincs forrás megadva",
     "No href specified when installing app from http" : "Az alkalmazás http-n keresztül történő telepítéséhez nincs href hivetkozás megadva",
     "No path specified when installing app from local file" : "Az alkalmazás helyi telepítéséhez nincs útvonal (mappa) megadva",
     "Archives of type %s are not supported" : "A(z) %s típusú tömörített állomány nem támogatott",
     "Failed to open archive when installing app" : "Nem sikerült megnyitni a tömörített állományt a telepítés során",
     "App does not provide an info.xml file" : "Az alkalmazás nem szolgáltatott info.xml file-t",
+    "App cannot be installed because appinfo file cannot be read." : "Az alkalmazást nem telepíthető mert az alkalmazás-infó file nem olvasható.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Az aláírás nem ellenőrizhető. Lépj kapcsolatba az alkalmazás fejlesztővel és ellenörízd az admin képernyődet.",
     "App can't be installed because of not allowed code in the App" : "Az alkalmazást nem lehet telepíteni, mert abban nem engedélyezett programkód szerepel",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Az alkalmazás nem telepíthető, mert nem kompatibilis az ownCloud jelen verziójával.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Az alkalmazást nem lehet telepíteni, mert tartalmazza a \n<shipped>\ntrue\n</shipped>\ncímkét, ami a nem szállított alkalmazások esetén nem engedélyezett",
-    "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
-    "Authentication error" : "Azonosítási hiba",
-    "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
-    "Unknown user" : "Ismeretlen felhasználó",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Az alkalmazást nem telepíthető mert a verzió az info.xml-ben nem azonos azzal amit az alkalmazás boltban van feltüntetve.",
+    "%s enter the database username and name." : "%s adja meg az adatbázis felhasználó nevét és az adatbázi nevét.",
     "%s enter the database username." : "%s adja meg az adatbázist elérő felhasználó login nevét.",
     "%s enter the database name." : "%s adja meg az adatbázis nevét.",
     "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
@@ -68,13 +65,14 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név és/vagy jelszó érvénytelen",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Csak saját felelősségre használja!",
     "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux-alapú kiszolgálót használni.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32-bites PHP környezetben fut és az open_basedir a php.ini-ben van konfigurálva. A 4GB-nál nagyobb fájlok és problémákhoz vezetnek és nagy akadályt jelentenek.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Kérlek távolítsd el az open_basedir beállítást a php.ini-ből, vagy válts 64bit-es PHP-ra.",
     "Set an admin username." : "Állítson be egy felhasználói nevet az adminisztrációhoz.",
     "Set an admin password." : "Állítson be egy jelszót az adminisztrációhoz.",
     "Can't create or write into the data directory %s" : "Nem sikerült  létrehozni vagy irni  a \"data\" könyvtárba %s",
     "Invalid Federated Cloud ID" : "Érvénytelen Egyesített Felhő Azonosító",
     "%s shared »%s« with you" : "%s megosztotta Önnel ezt:  »%s«",
-    "%s via %s" : "%s über %s",
+    "%s via %s" : "%s - %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s megosztása sikertelen, mert a megosztási alrendszer nem engedi a %l típus megosztását",
     "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
     "You are not allowed to share %s" : "Önnek nincs jogosultsága %s megosztására",
@@ -87,6 +85,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja a %s csoportnak",
     "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános linkek csak jelszóval védetten használhatók",
     "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a linkekkel történő megosztás nincs engedélyezve",
+    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet létrehozni egyesített megosztást.",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s megosztása sikertelen, mert %s nem található, talán a szerver jelenleg nem elérhető.",
     "Share type %s is not valid for %s" : "A %s megosztási típus nem érvényes %s-re",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a megadottak túllépik a %s-re érvényes jogosultságokat",
@@ -102,18 +101,32 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s megosztása nem sikerült, mert %s megosztási alrendszere nem találja",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban",
+    "Expiration date is in the past" : "Múltbéli lejárati idő.",
     "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
     "Apps" : "Alkalmazások",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek fordulhatnak elő: \"a-z\", \"A-Z\", \"0-9\", és \"_.@-\"",
     "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
     "A valid password must be provided" : "Érvényes jelszót kell megadnia",
     "The username is already being used" : "Ez a bejelentkezési név már foglalt",
+    "Help" : "Súgó",
+    "Personal" : "Személyes",
+    "Users" : "Felhasználók",
+    "Admin" : "Adminsztráció",
+    "Recommended" : "Ajánlott",
+    "No app name specified" : "Nincs az alkalmazás név megadva.",
+    "web services under your control" : "webszolgáltatások saját kézben",
+    "File is currently busy, please try again later" : "A fájl jelenleg elfoglalt, kérjük próbáld újra később!",
+    "Can't read file" : "Nem olvasható a fájl",
+    "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
+    "Authentication error" : "Azonosítási hiba",
+    "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
+    "Unknown user" : "Ismeretlen felhasználó",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nincs telepítve adatbázis-meghajtóprogram (sqlite, mysql vagy postgresql).",
     "Microsoft Windows Platform is not supported" : "Microsoft Windows platform nem támogatott",
     "Cannot write into \"config\" directory" : "Nem írható a \"config\" könyvtár",
     "Cannot write into \"apps\" directory" : "Nem írható az \"apps\" könyvtár",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ez rendszerint úgy oldható meg, hogy %sírási jogot adunk a webszervernek az app könyvtárra%s, vagy letiltjuk a config fájlban az appstore használatát.",
     "Cannot create \"data\" directory (%s)" : "Nem sikerült létrehozni a \"data\" könyvtárt (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ez rendszerint úgy oldható meg, hogy <a href=\"%s\" target=\"_blank\">írásjogot adunk a webszervernek a gyökérkönyvtárra</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Az elérési problémák rendszerint megoldhatók azzal, ha a %swebszervernek írásjogot adunk a gyökérkönyvtárra%s.",
     "Setting locale to %s failed" : "A lokalizáció %s-re való állítása nem sikerült",
     "Please install one of these locales on your system and restart your webserver." : "Kérjük állítsa be a következő lokalizációk valamelyikét a rendszeren és indítsa újra a webszervert!",
