@@ -17,14 +17,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "다음 플랫폼을 지원합니다: %s",
     "ownCloud %s or higher is required." : "ownCloud 버전 %s 이상이 필요합니다.",
     "ownCloud %s or lower is required." : "ownCloud %s 이하가 필요합니다.",
-    "Help" : "도움말",
-    "Personal" : "개인",
-    "Users" : "사용자",
-    "Admin" : "관리자",
-    "Recommended" : "추천",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "앱 \"%s\"이(가) 이 버전의 ownCloud와 호환되지 않으므로 설치할 수 없습니다.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "앱 \"%s\"의 다음 의존성을 만족하지 못하므로 설치할 수 없습니다: %s",
-    "No app name specified" : "앱 이름이 지정되지 않았습니다.",
     "Unknown filetype" : "알 수 없는 파일 형식",
     "Invalid image" : "잘못된 사진",
     "today" : "오늘",
@@ -37,7 +29,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n시간 전"],
     "_%n minute ago_::_%n minutes ago_" : ["%n분 전"],
     "seconds ago" : "초 전",
-    "web services under your control" : "내가 관리하는 웹 서비스",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "id: %s인 모듈이 존재하지 않습니다. 앱 설정에서 활성화하거나 관리자에게 연락하십시오.",
     "Empty filename is not allowed" : "파일 이름을 비워 둘 수 없음",
     "Dot files are not allowed" : "점으로 시작하는 파일은 허용되지 않음",
@@ -45,8 +36,6 @@ OC.L10N.register(
     "File name is a reserved word" : "파일 이름이 예약된 단어임",
     "File name contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
     "File name is too long" : "파일 이름이 너무 김",
-    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
-    "Can't read file" : "파일을 읽을 수 없음",
     "App directory already exists" : "앱 디렉터리가 이미 존재합니다.",
     "Can't create app folder. Please fix permissions. %s" : "앱 폴더를 만들 수 없습니다. 권한을 수정하십시오. %s",
     "Archive does not contain a directory named %s" : "압축 파일에 디렉터리 %s이(가) 없습니다",
@@ -59,11 +48,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "앱에 허용되지 않는 코드가 있어서 앱을 설치할 수 없습니다.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "현재 ownCloud 버전과 호환되지 않기 때문에 앱을 설치할 수 없습니다.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "출시되지 않은 앱에 허용되지 않는 <shipped>true</shipped> 태그를 포함하고 있기 때문에 앱을 설치할 수 없습니다.",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "info.xml/version에 포함된 버전과 앱 스토어에 보고된 버전이 같지 않아서 앱을 설치할 수 없습니다.",
-    "Application is not enabled" : "앱이 활성화되지 않았습니다",
-    "Authentication error" : "인증 오류",
-    "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
-    "Unknown user" : "알려지지 않은 사용자",
     "%s enter the database username." : "%s 데이터베이스 사용자 이름을 입력해 주십시오.",
     "%s enter the database name." : "%s 데이터베이스 이름을 입력하십시오.",
     "%s you may not use dots in the database name" : "%s 데이터베이스 이름에는 마침표를 사용할 수 없습니다",
@@ -82,12 +66,12 @@ OC.L10N.register(
     "Set an admin password." : "관리자의 암호를 설정합니다.",
     "Can't create or write into the data directory %s" : "데이터 디렉터리 %s을(를) 만들거나 기록할 수 없음",
     "Invalid Federated Cloud ID" : "잘못된 연합 클라우드 ID",
-    "%s shared »%s« with you" : "%s 님이 %s을(를) 공유하였습니다",
+    "%s shared »%s« with you" : "%s 님이 %s을(를) 공유했습니다",
     "%s via %s" : "%s(%s 경유)",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s을(를) 공유할 수 없습니다. 백엔드에서 %i 형식의 공유를 허용하지 않습니다",
     "Sharing %s failed, because the file does not exist" : "%s을(를) 공유할 수 없습니다. 파일이 존재하지 않습니다",
     "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
-    "Sharing %s failed, because the user %s is the item owner" : "%s을(를) 공유할 수 없습니다. %s 님이 항목을 소유하고 있습니다",
+    "Sharing %s failed, because you can not share with yourself" : "%s을(를) 공유할 수 없습니다. 자기 자신과 공유할 수 없습니다",
     "Sharing %s failed, because the user %s does not exist" : "%s을(를) 공유할 수 없습니다. 사용자 %s이(가) 존재하지 않습니다",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s을(를) 공유할 수 없습니다. 사용자 %s 님은 %s 님이 회원인 어떠한 그룹에도 속해 있지 않습니다",
     "Sharing %s failed, because this item is already shared with %s" : "%s을(를) 공유할 수 없습니다. 이미 %s 님과 공유되어 있습니다",
@@ -96,6 +80,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "%s을(를) 공유할 수 없습니다. %s 님이 그룹 %s의 구성원이 아닙니다",
     "You need to provide a password to create a public link, only protected links are allowed" : "공개 링크를 만들려면 암호를 입력해야 합니다. 보호된 링크만 사용 가능합니다",
     "Sharing %s failed, because sharing with links is not allowed" : "%s을(를) 공유할 수 없습니다. 링크 공유가 허용되지 않았습니다",
+    "Not allowed to create a federated share with the same user" : "같은 사용자와 연합 공유를 만들 수 없음",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s을(를) 공유할 수 없습니다. %s을(를) 찾을 수 없습니다. 서버에 접근하지 못할 수도 있습니다.",
     "Share type %s is not valid for %s" : "공유 형식 %s을(를) %s에 대해서 사용할 수 없음",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s의 권한을 설정할 수 없습니다. %s 님에게 허용된 것 이상의 권한을 필요로 합니다",
@@ -106,17 +91,31 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "공유 백엔드 %s에서 OCP\\Share_Backend 인터페이스를 구현해야 함",
     "Sharing backend %s not found" : "공유 백엔드 %s을(를) 찾을 수 없음",
     "Sharing backend for %s not found" : "%s의 공유 백엔드를 찾을 수 없음",
-    "Sharing %s failed, because the user %s is the original sharer" : "%s을(를) 공유할 수 없습니다. %s 님이 원래 공유한 사람입니다",
+    "Sharing failed, because the user %s is the original sharer" : "공유할 수 없습니다. 사용자 %s이(가) 원 공유자입니다",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s을(를) 공유할 수 없습니다. %s 님에게 허용된 것 이상의 권한을 필요로 합니다",
     "Sharing %s failed, because resharing is not allowed" : "%s을(를) 공유할 수 없습니다. 다시 공유할 수 없습니다",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s을(를) 공유할 수 없습니다. %s의 공유 백엔드에서 원본 파일을 찾을 수 없습니다",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s을(를) 공유할 수 없습니다. 파일 캐시에서 찾을 수 없습니다",
     "Could not find category \"%s\"" : "분류 \"%s\"을(를) 찾을 수 없습니다.",
     "Apps" : "앱",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "사용자 이름에는 다음과 같은 문자만 사용할 수 있습니다: \"a-z\", \"A-Z\", \"0-9\", \"_.@-\"",
     "A valid username must be provided" : "올바른 사용자 이름을 입력해야 합니다",
     "A valid password must be provided" : "올바른 암호를 입력해야 합니다",
     "The username is already being used" : "사용자 이름이 이미 존재합니다",
+    "Help" : "도움말",
+    "Personal" : "개인",
+    "Users" : "사용자",
+    "Admin" : "관리자",
+    "Recommended" : "추천",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "앱 \"%s\"이(가) 이 버전의 ownCloud와 호환되지 않으므로 설치할 수 없습니다.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "앱 \"%s\"의 다음 의존성을 만족하지 못하므로 설치할 수 없습니다: %s",
+    "No app name specified" : "앱 이름이 지정되지 않았습니다.",
+    "web services under your control" : "내가 관리하는 웹 서비스",
+    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
+    "Can't read file" : "파일을 읽을 수 없음",
+    "Application is not enabled" : "앱이 활성화되지 않았습니다",
+    "Authentication error" : "인증 오류",
+    "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
+    "Unknown user" : "알려지지 않은 사용자",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "데이터베이스 드라이버(sqlite, mysql, postgresql)가 설치되지 않았습니다.",
     "Microsoft Windows Platform is not supported" : "Microsoft Windows 플랫폼은 지원하지 않음",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "ownCloud 서버를 Microsoft Windows 환경에서 실행하는 것은 지원되지 않습니다. 서버를 이전할 수 없다면 가상 Linux 서버를 사용하는 것을 추천합니다. Linux 패키지 및 쉽게 배포 가능한 가상 머신 이미지는 <a href=\"%s\">%s</a>에서 찾을 수 있습니다. 기존 설치본을 Linux로 이전할 때 참고할 팁과 이전 스크립트는 <a href=\"%s\">문서</a>에서 찾을 수 있습니다.",
@@ -124,7 +123,6 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "\"apps\" 디렉터리에 기록할 수 없습니다",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "%sapps 디렉터리에 웹 서버 쓰기 권한%s을 주거나 설정 파일에서 앱 스토어를 비활성화하면 해결됩니다.",
     "Cannot create \"data\" directory (%s)" : "\"data\" 디렉터리를 만들 수 없음(%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "<a href=\"%s\" target=\"_blank\">루트 디렉터리에 웹 서버 쓰기 권한</a>을 주면 해결됩니다.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "%s루트 디렉터리에 웹 서버 쓰기 권한%s을 주면 해결됩니다.",
     "Setting locale to %s failed" : "로캘을 %s(으)로 설정할 수 없음",
     "Please install one of these locales on your system and restart your webserver." : "다음 중 하나 이상의 로캘을 시스템에 설치하고 웹 서버를 다시 시작하십시오.",
@@ -140,14 +138,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "서버 관리자에게 웹 서버 재시작을 요청하십시오.",
     "PostgreSQL >= 9 required" : "PostgreSQL 버전 9 이상이 필요합니다",
     "Please upgrade your database version" : "데이터베이스 버전을 업그레이드 하십시오",
-    "Error occurred while checking PostgreSQL version" : "PostgreSQL 버전을 확인하는 중 오류가 발생하였습니다",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "PostgreSQL 버전 9 이상이 있는지 확인하시고, 자세한 정보는 로그를 확인하십시오",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오.",
     "Data directory (%s) is readable by other users" : "데이터 디렉터리(%s)를 다른 사용자가 읽을 수 있음",
     "Data directory (%s) must be an absolute path" : "데이터 디렉터리(%s)는 반드시 절대 경로여야 함",
     "Check the value of \"datadirectory\" in your configuration" : "설정 중 \"datadirectory\" 값을 확인하십시오",
     "Data directory (%s) is invalid" : "데이터 디렉터리(%s)가 잘못됨",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "데이터 디렉터리의 최상위 경로에 \".ocdata\" 파일이 있는지 확인하십시오.",
-    "Could not obtain lock type %d on \"%s\"." : "잠금 형식 %d을(를) \"%s\"에 대해 얻을 수 없습니다."
+    "Could not obtain lock type %d on \"%s\"." : "잠금 형식 %d을(를) \"%s\"에 대해 얻을 수 없습니다.",
+    "Storage not available" : "저장소를 사용할 수 없음"
 },
 "nplurals=1; plural=0;");
