@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Blijkbaar is de voorbeeldconfiguratie gekopieerd. Dit kan uw installatie beschadigen en wordt niet dan ook ondersteund. Lees de documentatie voordat u wijzigingen aan config.php doorvoert",
     "PHP %s or higher is required." : "PHP %s of hoger vereist.",
     "PHP with a version lower than %s is required." : "PHP met een versie lager dan %s is vereist.",
+    "%sbit or higher PHP required." : "%sbit of hogere PHP vereist.",
     "Following databases are supported: %s" : "De volgende databases worden ondersteund: %s",
     "The command line tool %s could not be found" : "Commandoregel tool %s is niet gevonden",
     "The library %s is not available." : "Library %s is niet beschikbaar.",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "De volgende platformen worden ondersteund: %s",
     "ownCloud %s or higher is required." : "ownCloud %s of hoger vereist.",
     "ownCloud %s or lower is required." : "ownCloud %s of lager vereist.",
-    "Help" : "Help",
-    "Personal" : "Persoonlijk",
-    "Users" : "Gebruikers",
-    "Admin" : "Beheerder",
-    "Recommended" : "Aanbevolen",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" kan niet worden geïnstalleerd omdat deze niet compatible is met deze versie van ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan niet worden geïnstalleerd omdat de volgende afhankelijkheden niet zijn ingevuld: %s",
-    "No app name specified" : "Geen app naam opgegeven.",
     "Unknown filetype" : "Onbekend bestandsformaat",
     "Invalid image" : "Ongeldige afbeelding",
     "today" : "vandaag",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n uur geleden","%n uur geleden"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minuut geleden","%n minuten geleden"],
     "seconds ago" : "seconden geleden",
-    "web services under your control" : "Webdiensten in eigen beheer",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met id: %s bestaat niet. Activeer het in uw apps instellingen, of neem contact op met uw beheerder.",
     "Empty filename is not allowed" : "Een lege bestandsnaam is niet toegestaan",
     "Dot files are not allowed" : "Punt bestanden zijn niet toegestaan",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "Bestandsnaam is een gereserveerd woord",
     "File name contains at least one invalid character" : "De bestandsnaam bevat ten minste één verboden teken",
     "File name is too long" : "De bestandsnaam is te lang",
-    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
-    "Can't read file" : "Kan bestand niet lezen",
     "App directory already exists" : "App directory bestaat al",
     "Can't create app folder. Please fix permissions. %s" : "Kan de app map niet aanmaken, Herstel de permissies. %s",
     "Archive does not contain a directory named %s" : "Archief bevat geen directory genaamd %s",
@@ -56,15 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Archiefbestanden van type %s niet ondersteund",
     "Failed to open archive when installing app" : "Kon archiefbestand bij installatie van de app niet openen",
     "App does not provide an info.xml file" : "De app heeft geen info.xml bestand",
+    "App cannot be installed because appinfo file cannot be read." : "App kan niet worden geïnstalleerd, omdat appinfo bestand niet gelezen kan worden.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Handtekening kon niet worden geverifieerd. Nee contact op met de ontwikkelaar van de app en check uw beheerscherm.",
     "App can't be installed because of not allowed code in the App" : "De app kan niet worden geïnstalleerd wegens onjuiste code in de app",
-    "App can't be installed because it is not compatible with this version of ownCloud" : "De app kan niet worden geïnstalleerd omdat die niet compatible is met deze versie van ownCloud",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "De app kan niet worden geïnstallerd omdat het de <shipped>true</shipped> tag bevat die niet is toegestaan voor niet gepubliceerde apps",
-    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "De app kan niet worden geïnstalleerd omdat de versie in info.xml niet dezelfde is als de versie zoals die in de app store staat vermeld",
-    "Application is not enabled" : "De applicatie is niet actief",
-    "Authentication error" : "Authenticatie fout",
-    "Token expired. Please reload page." : "Token verlopen.  Herlaad de pagina.",
-    "Unknown user" : "Onbekende gebruiker",
+    "App can't be installed because it is not compatible with this version of ownCloud" : "De app kan niet worden geïnstalleerd, omdat die niet compatible is met deze versie van ownCloud",
+    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "De app kan niet worden geïnstalleerd, omdat het de <shipped>true</shipped> tag bevat die niet is toegestaan voor niet gepubliceerde apps",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "De app kan niet worden geïnstalleerd, omdat de versie in info.xml niet dezelfde is als de versie zoals die in de app store staat vermeld",
+    "%s enter the database username and name." : "%s voer de database gebruikersnaam en naam in .",
     "%s enter the database username." : "%s opgeven database gebruikersnaam.",
     "%s enter the database name." : "%s opgeven databasenaam.",
     "%s you may not use dots in the database name" : "%s er mogen geen puntjes in de databasenaam voorkomen",
@@ -114,6 +102,8 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Delen van %s is mislukt, omdat de share-backend voor %s de bron niet kon vinden",
     "Sharing %s failed, because the file could not be found in the file cache" : "Delen van %s is mislukt, omdat het bestand niet in de bestandscache kon worden gevonden",
     "Cannot increase permissions of %s" : "Kan de rechten van %s niet verruimen",
+    "Files can't be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijderrechten",
+    "Files can't be shared with create permissions" : "Bestanden kunnen niet worden gedeeld met creatie rechten",
     "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
     "Cannot set expiration date more than %s days in the future" : "Kan vervaldatum niet verder dan %s dagen in de toekomst instellen",
     "Could not find category \"%s\"" : "Kon categorie \"%s\" niet vinden",
@@ -123,6 +113,24 @@ OC.L10N.register(
     "Username contains whitespace at the beginning or at the end" : "De gebruikersnaam bevat spaties aan het begin of eind",
     "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
     "The username is already being used" : "De gebruikersnaam bestaat al",
+    "Login canceled by app" : "Inloggen geannuleerd door app",
+    "User disabled" : "Gebruiker gedeactiveerd",
+    "Help" : "Help",
+    "Personal" : "Persoonlijk",
+    "Users" : "Gebruikers",
+    "Admin" : "Beheerder",
+    "Recommended" : "Aanbevolen",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" kan niet worden geïnstalleerd, omdat het appinfo bestand niet gelezen kan worden.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" kan niet worden geïnstalleerd, omdat deze niet compatible is met deze versie van ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld: %s",
+    "No app name specified" : "Geen app naam opgegeven.",
+    "web services under your control" : "Webdiensten in eigen beheer",
+    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
+    "Can't read file" : "Kan bestand niet lezen",
+    "Application is not enabled" : "De applicatie is niet actief",
+    "Authentication error" : "Authenticatie fout",
+    "Token expired. Please reload page." : "Token verlopen.  Herlaad de pagina.",
+    "Unknown user" : "Onbekende gebruiker",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Geen database drivers (sqlite, mysql of postgres) geïnstalleerd.",
     "Microsoft Windows Platform is not supported" : "Microsoft Windows Platform wordt niet ondersteund",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Het draaien van een ownCloud server op het Microsoft Windows platform wordt niet ondersteund. We adviseren om een Linux server binnen een virtuele machine te gebruiken als u niet de mogelijkheid hebt om te migreren. Linux packages en eenvoudig te installeren virtuele machine images zijn te vinden op <a href=\"%s\">%s</a>. Voor migratie van bestaande installaties naar Linux vind u tips en migratiescripts in <a href=\"%s\">onze documentatie</a>.",
@@ -130,7 +138,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Kan niet schrijven naar de \"apps\" directory",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te %s geven op de appsdirectory %s of door de appstore te deactiveren in het configbestand.",
     "Cannot create \"data\" directory (%s)" : "Kan de \"data\" directory (%s) niet aanmaken",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dit kan worden hersteld door <a href=\"%s\" target=\"_blank\"> de webserver schrijfrechten te geven tot de hoofddirectory</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dit kan worden hersteld door <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> de webserver schrijfrechten te geven tot de hoofddirectory</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dit kan hersteld worden door de webserver schrijfrechten te %s geven op de hoofddirectory %s.",
     "Setting locale to %s failed" : "Instellen taal op %s mislukte",
     "Please install one of these locales on your system and restart your webserver." : "Installeer één van de talen op uw systeem en herstart uw webserver.",
@@ -140,6 +148,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Het in php.ini bijstellen hiervan laat ownCloud weer werken",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is ingesteld op \"%s\" in plaats van op de verwachte waarde \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Om dit op te lossen stel <code>mbstring.func_overload</code> in op <code>0</code> in uw php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "De laagste toegestane libxml2 versie is 2.7.0. Momenteel is %s is geïnstalleerd.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Om dit te herstellen, moet u de libxml2 versie bijwerken en uw webserver herstarten.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is blijkbaar zo ingesteld dat inline doc blokken worden gestript. Hierdoor worden verschillende kernmodules onbruikbaar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar worden ze nog steeds als ontbrekend aangegeven?",
