@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
-    "Sharing" : "Condivisione",
-    "Server-side encryption" : "Cifratura lato server",
-    "External Storage" : "Archiviazione esterna",
-    "Cron" : "Cron",
-    "Email server" : "Server di posta",
-    "Log" : "Log",
-    "Tips & tricks" : "Suggerimenti e trucchi",
-    "Updates" : "Aggiornamenti",
-    "Couldn't remove app." : "Impossibile rimuovere l'applicazione.",
-    "Language changed" : "Lingua modificata",
-    "Invalid request" : "Richiesta non valida",
-    "Authentication error" : "Errore di autenticazione",
-    "Admins can't remove themself from the admin group" : "Gli amministratori non possono rimuovere se stessi dal gruppo di amministrazione",
-    "Unable to add user to group %s" : "Impossibile aggiungere l'utente al gruppo %s",
-    "Unable to remove user from group %s" : "Impossibile rimuovere l'utente dal gruppo %s",
-    "Couldn't update app." : "Impossibile aggiornate l'applicazione.",
     "Wrong password" : "Password errata",
     "No user supplied" : "Non è stato fornito alcun utente",
+    "Authentication error" : "Errore di autenticazione",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Fornisci una password amministrativa di ripristino altrimenti tutti i dati degli utenti saranno persi.",
     "Wrong admin recovery password. Please check the password and try again." : "Password amministrativa di ripristino errata. Controlla la password e prova ancora.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Il motore non supporta la modifica della password, ma la chiave di cifratura dell'utente è stata aggiornata correttamente.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "Email salvata",
     "Your full name has been changed." : "Il tuo nome completo è stato cambiato.",
     "Unable to change full name" : "Impossibile cambiare il nome completo",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
+    "Sharing" : "Condivisione",
+    "Server-side encryption" : "Cifratura lato server",
+    "External Storage" : "Archiviazione esterna",
+    "Cron" : "Cron",
+    "Email server" : "Server di posta",
+    "Log" : "Log",
+    "Tips & tricks" : "Suggerimenti e trucchi",
+    "Updates" : "Aggiornamenti",
+    "Couldn't remove app." : "Impossibile rimuovere l'applicazione.",
+    "Language changed" : "Lingua modificata",
+    "Invalid request" : "Richiesta non valida",
+    "Admins can't remove themself from the admin group" : "Gli amministratori non possono rimuovere se stessi dal gruppo di amministrazione",
+    "Unable to add user to group %s" : "Impossibile aggiungere l'utente al gruppo %s",
+    "Unable to remove user from group %s" : "Impossibile rimuovere l'utente dal gruppo %s",
+    "Couldn't update app." : "Impossibile aggiornate l'applicazione.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sei sicuro di voler aggiungere \"{domain}\"  come dominio attendibile?",
     "Add trusted domain" : "Aggiungi dominio attendibile",
     "Migration in progress. Please wait until the migration is finished" : "Migrazione in corso. Attendi fino al completamento della migrazione",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Experimental" : "Sperimentale",
     "All" : "Tutti",
     "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
+    "The app will be downloaded from the app store" : "L'applicazione sarà scaricata dallo store delle applicazioni",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Le applicazioni ufficiali sono sviluppate da e con la comunità di ownCloud. Offrono le funzioni fondamentali di ownCloud e sono pronte per l'utilizzo in produzione.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Le applicazioni approvate sono sviluppate da sviluppatori affidabili e hanno passato un rapido controllo di sicurezza. Sono attivamente mantenute in un deposito aperto del codice e i loro responsabili le ritengono pronte sia per un utilizzo casuale che per un utilizzo continuativo.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Questa applicazione non è stata sottoposta a controlli di sicurezza, è nuova o notoriamente instabile. Installala a tuo rischio.",
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Disabilita",
     "Enable" : "Abilita",
     "Error while enabling app" : "Errore durante l'attivazione",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Errore: questa applicazione non può essere abilitata perché rende il server instabile",
+    "Error: could not disable broken app" : "Errore: impossibile disabilitare l'applicazione danneggiata",
+    "Error while disabling broken app" : "Errore durante la disabilitazione dell'applicazione danneggiata",
     "Updating...." : "Aggiornamento in corso...",
     "Error while updating app" : "Errore durante l'aggiornamento",
     "Updated" : "Aggiornato",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Disinstalla",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'applicazione è stata abilitata, ma deve essere aggiornata. Sarai rediretto alla pagina di aggiornamento in 5 secondi.",
     "App update" : "Aggiornamento applicazione",
-    "No apps found for \"{query}\"" : "Nessuna applicazione trovata per \"{query}\"",
+    "No apps found for {query}" : "Nessuna applicazione trovata per {query}",
+    "Disconnect" : "Disconnetti",
+    "Error while loading browser sessions and device tokens" : "Errore durante il caricamento delle sessioni del browser e dei token di dispositivo",
+    "Error while creating device token" : "Errore durante la creazione del token di dispositivo",
+    "Error while deleting the token" : "Errore durante l'eliminazione del token",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Si è verificato un errore. Carica un certificato PEM codificato in ASCII.",
     "Valid until {date}" : "Valido fino al {date}",
     "Delete" : "Elimina",
@@ -108,7 +116,10 @@ OC.L10N.register(
     "A valid password must be provided" : "Deve essere fornita una password valida",
     "A valid email must be provided" : "Deve essere fornito un indirizzo email valido",
     "__language_name__" : "Italiano",
+    "Unlimited" : "Illimitata",
     "Personal info" : "Informazioni personali",
+    "Sessions" : "Sessioni",
+    "App passwords" : "Password di applicazione",
     "Sync clients" : "Client di sincronizzazione",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tutto (problemi gravi, errori, avvisi, informazioni, debug)",
     "Info, warnings, errors and fatal issues" : "Informazioni, avvisi, errori e problemi gravi",
@@ -122,32 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php non sembra essere configurato correttamente per interrogare le variabili d'ambiente di sistema. Il test con getenv(\"PATH\") restituisce solo una risposta vuota.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Controlla la <a target=\"_blank\" href=\"%s\">documentazione di installazione↗</a>  per le note di configurazione di php e la configurazione del tuo server, in particolare quando utilizzi php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Controlla la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione di installazione↗</a>  per le note di configurazione di php e la configurazione del tuo server, in particolare quando utilizzi php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configurazione di sola lettura è stata abilitata. Ciò impedisce l'impostazione di alcune configurazioni tramite l'interfaccia web. Inoltre, i file devono essere resi scrivibili manualmente per ogni aggiornamento.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Il tuo database non è in esecuzione con il livello di isolamento delle transazioni \"READ COMMITTED\". Ciò può causare problemi quando diverse azioni sono eseguite in parallelo.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Il tuo server è in esecuzione su Microsoft Windows. Consigliamo vivamente Linux per un'esperienza utente ottimale.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "La versione di %1$s installata è anteriore alla %2$s, per motivi di stabilità e prestazioni, consigliamo di aggiornare a una versione di %1$s più recente.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Il modulo PHP 'fileinfo' non è presente. Consigliamo vivamente di abilitare questo modulo per ottenere risultati migliori con il rilevamento dei tipi MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale è disabilitato, ciò potrebbe comportare problemi di race condition. Abilita 'filelocking.enabled' nel config-php per evitare questi problemi. Vedi la <a target=\"_blank\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale è disabilitato, ciò potrebbe comportare problemi di race condition. Abilita 'filelocking.enabled' nel config-php per evitare questi problemi. Vedi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
     "System locale can not be set to a one which supports UTF-8." : "La localizzazione di sistema non può essere impostata a una che supporta UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Ciò significa che potrebbero esserci problemi con alcuni caratteri nei nomi dei file.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Consigliamo vivamente di installare i pacchetti richiesti sul tuo sistema per supportare una delle localizzazioni seguenti: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se la tua installazione non si trova nella radice del dominio e utilizza il cron di sistema, potrebbero esserci problemi con la generazione degli URL. Per evitare questi problemi, imposta l'opzione \"overwrite.cli.url\"  nel file config.php al percorso della radice del sito della tua installazione (Consigliato: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Non è stato possibile eseguire il job di cron tramite CLI. Sono apparsi i seguenti errori tecnici:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Leggi attentamente le  <a target=\"_blank\" href=\"%s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"#log-section\">log</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Leggi attentamente le  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"#log-section\">log</a>.",
     "All checks passed." : "Tutti i controlli passati.",
     "Open documentation" : "Apri la documentazione",
     "Allow apps to use the Share API" : "Consenti alle applicazioni di utilizzare le API di condivisione",
     "Allow users to share via link" : "Consenti agli utenti di condividere tramite collegamento",
-    "Enforce password protection" : "Imponi la protezione con password",
     "Allow public uploads" : "Consenti caricamenti pubblici",
-    "Allow users to send mail notification for shared files" : "Consenti agli utenti di inviare email di notifica per i file condivisi",
+    "Enforce password protection" : "Imponi la protezione con password",
     "Set default expiration date" : "Imposta data di scadenza predefinita",
+    "Allow users to send mail notification for shared files" : "Consenti agli utenti di inviare email di notifica per i file condivisi",
     "Expire after " : "Scadenza dopo",
     "days" : "giorni",
     "Enforce expiration date" : "Forza la data di scadenza",
     "Allow resharing" : "Consenti la ri-condivisione",
+    "Allow sharing with groups" : "Consentì la condivisione con gruppi",
     "Restrict users to only share with users in their groups" : "Limita gli utenti a condividere solo con gli utenti nei loro gruppi",
     "Allow users to send mail notification for shared files to other users" : "Consenti agli utenti di inviare email di notifica per i file condivisi con altri utenti",
     "Exclude groups from sharing" : "Escludi gruppi dalla condivisione",
@@ -194,7 +207,7 @@ OC.L10N.register(
     "What to log" : "Cosa registrare",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite è utilizzato come database. Per installazioni più grandi consigliamo di passare a un motore di database diverso.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "In particolar modo, quando si utilizza il client desktop per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Per migrare a un altro database, usa lo strumento da riga di comando: 'occ db:convert-type', o leggi la <a target=\"_blank\" href=\"%s\">documentazione ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Per migrare a un altro database, usa lo strumento da riga di comando: 'occ db:convert-type', o leggi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a>.",
     "How to do backups" : "Come creare delle copie di sicurezza",
     "Advanced monitoring" : "Monitoraggio avanzato",
     "Performance tuning" : "Ottimizzazione delle prestazioni",
@@ -210,6 +223,8 @@ OC.L10N.register(
     "Documentation:" : "Documentazione:",
     "User documentation" : "Documentazione utente",
     "Admin documentation" : "Documentazione di amministrazione",
+    "Visit website" : "Visita il sito web",
+    "Report a bug" : "Segnala un bug",
     "Show description …" : "Mostra descrizione...",
     "Hide description …" : "Nascondi descrizione...",
     "This app has an update available." : "Un aggiornamento di questa applicazione è disponibile.",
@@ -256,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Modifica password",
     "Language" : "Lingua",
     "Help translate" : "Migliora la traduzione",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Questi sono i client web, desktop e mobile che hanno effettuato attualmente l'accesso al tuo ownCloud.",
+    "Browser" : "Browser",
+    "Most recent activity" : "Attività più recenti",
+    "You've linked these apps." : "Hai collegato queste applicazioni.",
+    "Name" : "Nome",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Una password di applicazione è un codice di sicurezza che fornisce a un'applicazione o a un dispositivo i permessi per accedere al tuo account %s.",
+    "App name" : "Nome applicazione",
+    "Create new app password" : "Crea nuova password di applicazione",
+    "Use the credentials below to configure your app or device." : "Usa le credenziali seguenti per configurare l'applicazione o il dispositivo.",
+    "Username" : "Nome utente",
+    "Done" : "Completato",
     "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
     "Desktop client" : "Client desktop",
     "Android app" : "Applicazione Android",
@@ -268,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Mostra il motore utente",
     "Send email to new user" : "Invia email al nuovo utente",
     "Show email address" : "Mostra l'indirizzo email",
-    "Username" : "Nome utente",
     "E-Mail" : "Posta elettronica",
     "Create" : "Crea",
     "Admin Recovery Password" : "Password di ripristino amministrativa",
@@ -279,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Amministratori",
     "Default Quota" : "Quota predefinita",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Digita la quota di archiviazione (ad es.: \"512 MB\" or \"12 GB\")",
-    "Unlimited" : "Illimitata",
     "Other" : "Altro",
     "Full Name" : "Nome completo",
     "Group Admin for" : "Gruppo di amministrazione per",
