@@ -24,6 +24,7 @@ namespace Owncloud\Updater\Console;
 
 use Owncloud\Updater\Utils\DocLink;
 use Owncloud\Updater\Utils\Locator;
+use Owncloud\Updater\Utils\OccRunner;
 use Pimple\Container;
 use Symfony\Component\Console\Logger\ConsoleLogger;
 use Symfony\Component\Console\Output\ConsoleOutput;
@@ -32,7 +33,7 @@ use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\BufferedOutput;
 use Symfony\Component\Console\Output\OutputInterface;
 use Symfony\Component\Console\Command\Command;
-use \Symfony\Component\Process\Exception\ProcessFailedException;
+use Symfony\Component\Process\Exception\ProcessFailedException;
 
 /**
  * Class Application
@@ -128,6 +129,27 @@ class Application extends \Symfony\Component\Console\Application {
 		return $this->fallbackLogger;
 	}
 
+	public function initConfig(){
+		$configReader = $this->diContainer['utils.configReader'];
+		try {
+			$configReader->init();
+		} catch (\UnexpectedValueException $e){
+			// try fallback to localhost
+			preg_match_all('/https?:\/\/([^\/]*).*$/', $this->getEndpoint(), $matches);
+			if (isset($matches[1][0])){
+				$newEndPoint = str_replace($matches[1][0], 'localhost', $this->getEndpoint());
+				$this->setEndpoint($newEndPoint);
+				try {
+					$configReader->init();
+				} catch (\UnexpectedValueException $e){
+					// fallback to CLI
+					$this->diContainer['utils.occrunner']->setCanUseProcess(true);
+					$configReader->init();
+				}
+			}
+		}
+	}
+
 	/**
 	 * Log exception with trace
 	 * @param \Exception $e
@@ -147,16 +169,18 @@ class Application extends \Symfony\Component\Console\Application {
 	 * @throws \Exception
 	 */
 	public function doRun(InputInterface $input, OutputInterface $output){
+		$commandName = $this->getCommandName($input);
 		try{
-			$configReader = $this->diContainer['utils.configReader'];
-			$commandName = $this->getCommandName($input);
+			$this->assertOwnCloudFound();
 			try{
-				$configReader->init();
-				$this->diContainer['utils.docLink'] = function($c){
-					$locator = $c['utils.locator'];
-					$installedVersion = implode('.', $locator->getInstalledVersion());
-					return new DocLink($installedVersion);
-				};
+				$this->initConfig();
+				if (!isset($this->diContainer['utils.docLink'])) {
+					$this->diContainer['utils.docLink'] = function ($c) {
+						$locator = $c['utils.locator'];
+						$installedVersion = implode('.', $locator->getInstalledVersion());
+						return new DocLink($installedVersion);
+					};
+				}
 			} catch (ProcessFailedException $e){
 				if (!in_array($commandName, $this->allowFailure)){
 					$this->logException($e);
@@ -169,13 +193,17 @@ class Application extends \Symfony\Component\Console\Application {
 				}
 			}
 			// TODO: check if the current command needs a valid OC instance
-			$this->assertOwnCloudFound();
-			
-			return parent::doRun($input, $output);
+			if (!isset($this->diContainer['logger'])) {
+				$locator = $this->diContainer['utils.locator'];
+				$this->initLogger($locator->getDataDir());
+			}
 		} catch (\Exception $e){
-			$this->logException($e);
-			throw $e;
+			if (!in_array($commandName, $this->allowFailure)){
+				$this->logException($e);
+				throw $e;
+			}
 		}
+		return parent::doRun($input, $output);
 	}
 
 	/**
@@ -190,7 +218,7 @@ class Application extends \Symfony\Component\Console\Application {
 			$command->setContainer($this->getContainer());
 			$commandName = $this->getCommandName($input);
 			$this->getLogger()->info('Execution of ' . $commandName . ' command started');
-			if (!empty($command->getMessage())){
+			if ($command->getMessage()!==''){
 				$message = sprintf('<info>%s</info>', $command->getMessage());
 				$output->writeln($message);
 			}
@@ -225,28 +253,25 @@ class Application extends \Symfony\Component\Console\Application {
 	 * Check for ownCloud instance
 	 * @throws \RuntimeException
 	 */
-	protected function assertOwnCloudFound(){
+	public function assertOwnCloudFound(){
 		$container = $this->getContainer();
 		/** @var Locator $locator */
 		$locator = $container['utils.locator'];
 		$fsHelper = $container['utils.filesystemhelper'];
-
-		// assert minimum version
-		$installedVersion = implode('.', $locator->getInstalledVersion());
-		if (version_compare($installedVersion, '9.0.0', '<')){
-			throw new \RuntimeException("Minimum ownCloud version 9.0.0 is required for the updater - $installedVersion was found in " . $locator->getOwnCloudRootPath());
-		}
+		/** @var OccRunner $occRunner */
+		$occRunner = $container['utils.occrunner'];
 
 		// has to be installed
 		$file = $locator->getPathToConfigFile();
-		if (!file_exists($file) || !is_file($file)){
-			throw new \RuntimeException('ownCloud in ' . dirname(dirname($file)) . ' is not installed.');
-		}
+		$this->assertFileExists($file, 'ownCloud in ' . dirname(dirname($file)) . ' is not installed.');
 
 		// version.php should exist
 		$file = $locator->getPathToVersionFile();
-		if (!file_exists($file) || !is_file($file)){
-			throw new \RuntimeException('ownCloud is not found in ' . dirname($file));
+		$this->assertFileExists($file, 'ownCloud is not found in ' . dirname($file));
+
+		$status = $occRunner->runJson('status');
+		if (!isset($status['installed'])  || $status['installed'] != 'true'){
+			throw new \RuntimeException('ownCloud in ' . dirname($file) . ' is not installed.');
 		}
 
 		// datadir should exist
@@ -260,8 +285,10 @@ class Application extends \Symfony\Component\Console\Application {
 			throw new \RuntimeException('Datadirectory ' . $dataDir . ' is not writable.');
 		}
 
-		if (!isset($this->diContainer['logger'])) {
-			$this->initLogger($dataDir);
+		// assert minimum version
+		$installedVersion = implode('.', $locator->getInstalledVersion());
+		if (version_compare($installedVersion, '9.0.0', '<')){
+			throw new \RuntimeException("Minimum ownCloud version 9.0.0 is required for the updater - $installedVersion was found in " . $locator->getOwnCloudRootPath());
 		}
 
 		if (!$fsHelper->fileExists($locator->getUpdaterBaseDir())){
@@ -275,4 +302,14 @@ class Application extends \Symfony\Component\Console\Application {
 			$fsHelper->mkdir($locator->getCheckpointDir());
 		}
 	}
+
+	/**
+	 * @param string $path
+	 * @param string $message
+	 */
+	protected function assertFileExists($path, $message){
+		if (!file_exists($path) || !is_file($path)){
+			throw new \RuntimeException($message);
+		}
+	}
 }
