@@ -72,10 +72,10 @@ class Checkpoint {
 				$this->fsHelper->copyr($coreItem, $cpItemPath, true);
 			}
 			//copy config.php
-			$configDirSrc = $this->locator->getOwncloudRootPath() . '/config';
+			$configDirSrc = $this->locator->getOwnCloudRootPath() . '/config';
 			$configDirDst = $checkpointCorePath . '/config';
 			$this->fsHelper->copyr($configDirSrc, $configDirDst, true);
-
+			
 			$checkpointAppPath = $checkpointPath . '/' . self::APP_DIR;
 			$this->fsHelper->mkdir($checkpointAppPath);
 			$appManager = Application::$container['utils.appmanager'];
@@ -105,7 +105,7 @@ class Checkpoint {
 	public function restore($checkpointId){
 		$this->assertCheckpointExists($checkpointId);
 		$checkpointDir = $this->locator->getCheckpointDir() . '/' . $checkpointId;
-		$ocRoot = $this->locator->getOwncloudRootPath();
+		$ocRoot = $this->locator->getOwnCloudRootPath();
 		$this->fsHelper->copyr($checkpointDir . '/' . self::CORE_DIR, $ocRoot, false);
 		$this->fsHelper->copyr($checkpointDir . '/' . self::APP_DIR, $ocRoot . '/' . self::APP_DIR, false);
 	}
